# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 75 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Numeric_Value=9}
#         \p{Nv=9}
#         \p{Is_Numeric_Value=9}
#         \p{Is_Nv=9}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Nv: 9}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0039		
0669		
06F9		
07C9		
096F		
09EF		
0A6F		
0AEF		
0B6F		
0BEF		
0C6F		
0CEF		
0D6F		
0E59		
0ED9		
0F29		
1049		
1099		
1371		
17E9		
17F9		
1819		
194F		
19D9		
1A89		
1A99		
1B59		
1BB9		
1C49		
1C59		
2079		
2089		
2168		
2178		
2468		
247C		
2490		
24FD		
277E		
2788		
2792		
3029		
3228		
3288		
4E5D		
5EFE		
7396		
A629		
A6EE		
A8D9		
A909		
A9D9		
AA59		
ABF9		
FF19		
1010F		
104A9		
10E68		
12407		
1240E		
12414		
1241D		
1242B		
12446	12449	 # [4]
1D368		
1D7D7		
1D7E1		
1D7EB		
1D7F5		
1D7FF		
1F10A		
2F890		
END
