# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 10_307 code points in Unicode Version 5.2.0 that
# match any of the following regular expression constructs:
# 
#         \p{Age=3.0}
#         \p{Is_Age=3.0}
# 
#     Meaning: Code point's usage was introduced in version 3.0
# 
#     Note: See also Property 'Present_In'
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Age: 3.0}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
01F6	01F9	 # [4]
0218	021F	 # [8]
0222	0233	 # [18]
02A9	02AD	 # [5]
02DF		
02EA	02EE	 # [5]
0346	034E	 # [9]
0362		
03D7		
03DB		
03DD		
03DF		
03E1		
0400		
040D		
0450		
045D		
0488	0489	 # [2]
048C	048F	 # [4]
04EC	04ED	 # [2]
058A		
0653	0655	 # [3]
06B8	06B9	 # [2]
06BF		
06CF		
06FA	06FE	 # [5]
0700	070D	 # [14]
070F	072C	 # [30]
0730	074A	 # [27]
0780	07B0	 # [49]
0D82	0D83	 # [2]
0D85	0D96	 # [18]
0D9A	0DB1	 # [24]
0DB3	0DBB	 # [9]
0DBD		
0DC0	0DC6	 # [7]
0DCA		
0DCF	0DD4	 # [6]
0DD6		
0DD8	0DDF	 # [8]
0DF2	0DF4	 # [3]
0F6A		
0F96		
0FAE	0FB0	 # [3]
0FB8		
0FBA	0FBC	 # [3]
0FBE	0FCC	 # [15]
0FCF		
1000	1021	 # [34]
1023	1027	 # [5]
1029	102A	 # [2]
102C	1032	 # [7]
1036	1039	 # [4]
1040	1059	 # [26]
1200	1206	 # [7]
1208	1246	 # [63]
1248		
124A	124D	 # [4]
1250	1256	 # [7]
1258		
125A	125D	 # [4]
1260	1286	 # [39]
1288		
128A	128D	 # [4]
1290	12AE	 # [31]
12B0		
12B2	12B5	 # [4]
12B8	12BE	 # [7]
12C0		
12C2	12C5	 # [4]
12C8	12CE	 # [7]
12D0	12D6	 # [7]
12D8	12EE	 # [23]
12F0	130E	 # [31]
1310		
1312	1315	 # [4]
1318	131E	 # [7]
1320	1346	 # [39]
1348	135A	 # [19]
1361	137C	 # [28]
13A0	13F4	 # [85]
1401	1676	 # [630]
1680	169C	 # [29]
16A0	16F0	 # [81]
1780	17DC	 # [93]
17E0	17E9	 # [10]
1800	180E	 # [15]
1810	1819	 # [10]
1820	1877	 # [88]
1880	18A9	 # [42]
202F		
2048	204D	 # [6]
20AD	20AF	 # [3]
20E2	20E3	 # [2]
2139	213A	 # [2]
2183		
21EB	21F3	 # [9]
2301		
237B		
237D	239A	 # [30]
2425	2426	 # [2]
25F0	25F7	 # [8]
2619		
2670	2671	 # [2]
2800	28FF	 # [256]
2E80	2E99	 # [26]
2E9B	2EF3	 # [89]
2F00	2FD5	 # [214]
2FF0	2FFB	 # [12]
3038	303A	 # [3]
303E		
31A0	31B7	 # [24]
3400	4DB5	 # [6582]
A000	A48C	 # [1165]
A490	A4A1	 # [18]
A4A4	A4B3	 # [16]
A4B5	A4C0	 # [12]
A4C2	A4C4	 # [3]
A4C6		
FB1D		
FFF9	FFFB	 # [3]
END
