# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 1244 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Script=Latin}
#         \p{Sc=Latn}
#         \p{Is_Script=Latin}
#         \p{Is_Sc=Latn}
# 
#         \p{Latin}
#         \p{Is_Latin}
#         \p{Latn}
#         \p{Is_Latn}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Sc: Latin}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0041	005A	 # [26]
0061	007A	 # [26]
00AA		
00BA		
00C0	00D6	 # [23]
00D8	00F6	 # [31]
00F8	02B8	 # [449]
02E0	02E4	 # [5]
1D00	1D25	 # [38]
1D2C	1D5C	 # [49]
1D62	1D65	 # [4]
1D6B	1D77	 # [13]
1D79	1DBE	 # [70]
1E00	1EFF	 # [256]
2071		
207F		
2090	2094	 # [5]
212A	212B	 # [2]
2132		
214E		
2160	2188	 # [41]
2C60	2C7F	 # [32]
A722	A787	 # [102]
A78B	A78C	 # [2]
A7FB	A7FF	 # [5]
FB00	FB06	 # [7]
FF21	FF3A	 # [26]
FF41	FF5A	 # [26]
END
