# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 94 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Numeric_Value=2}
#         \p{Nv=2}
#         \p{Is_Numeric_Value=2}
#         \p{Is_Nv=2}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Nv: 2}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0032		
00B2		
0662		
06F2		
07C2		
0968		
09E8		
0A68		
0AE8		
0B68		
0BE8		
0C68		
0C7A		
0C7D		
0CE8		
0D68		
0E52		
0ED2		
0F22		
1042		
1092		
136A		
17E2		
17F2		
1812		
1948		
19D2		
1A82		
1A92		
1B52		
1BB2		
1C42		
1C52		
2082		
2161		
2171		
2461		
2475		
2489		
24F6		
2777		
2781		
278B		
3022		
3193		
3221		
3281		
3483		
4E8C		
5169		
5F0D		
5F10		
8CAE		
8CB3		
8D30		
A622		
A6E7		
A8D2		
A902		
A9D2		
AA52		
ABF2		
F978		
FF12		
10108		
1015B	1015E	 # [4]
103D2		
104A2		
10859		
1091A		
10A41		
10B59		
10B79		
10E61		
12400		
12416		
1241F		
12423		
1242D		
12435		
1244A		
12450		
12459		
1D361		
1D7D0		
1D7DA		
1D7E4		
1D7EE		
1D7F8		
1F103		
22390		
END
