# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 3467 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Decomposition_Type=Non_Canonical}
#         \p{Dt=Non_Canon}
#         \p{Is_Decomposition_Type=Non_Canonical}
#         \p{Is_Dt=Non_Canon}
# 
#     Note: Union of all non-canonical decompositions
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Dt: Non_Canonical}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
00A0		
00A8		
00AA		
00AF		
00B2	00B5	 # [4]
00B8	00BA	 # [3]
00BC	00BE	 # [3]
0132	0133	 # [2]
013F	0140	 # [2]
0149		
017F		
01C4	01CC	 # [9]
01F1	01F3	 # [3]
02B0	02B8	 # [9]
02D8	02DD	 # [6]
02E0	02E4	 # [5]
037A		
0384		
03D0	03D2	 # [3]
03D5	03D6	 # [2]
03F0	03F2	 # [3]
03F4	03F5	 # [2]
03F9		
0587		
0675	0678	 # [4]
0E33		
0EB3		
0EDC	0EDD	 # [2]
0F0C		
0F77		
0F79		
10FC		
1D2C	1D2E	 # [3]
1D30	1D3A	 # [11]
1D3C	1D4D	 # [18]
1D4F	1D6A	 # [28]
1D78		
1D9B	1DBF	 # [37]
1E9A		
1FBD		
1FBF	1FC0	 # [2]
1FFE		
2002	200A	 # [9]
2011		
2017		
2024	2026	 # [3]
202F		
2033	2034	 # [2]
2036	2037	 # [2]
203C		
203E		
2047	2049	 # [3]
2057		
205F		
2070	2071	 # [2]
2074	208E	 # [27]
2090	2094	 # [5]
20A8		
2100	2103	 # [4]
2105	2107	 # [3]
2109	2113	 # [11]
2115	2116	 # [2]
2119	211D	 # [5]
2120	2122	 # [3]
2124		
2128		
212C	212D	 # [2]
212F	2131	 # [3]
2133	2139	 # [7]
213B	2140	 # [6]
2145	2149	 # [5]
2150	217F	 # [48]
2189		
222C	222D	 # [2]
222F	2230	 # [2]
2460	24EA	 # [139]
2A0C		
2A74	2A76	 # [3]
2C7C	2C7D	 # [2]
2D6F		
2E9F		
2EF3		
2F00	2FD5	 # [214]
3000		
3036		
3038	303A	 # [3]
309B	309C	 # [2]
309F		
30FF		
3131	318E	 # [94]
3192	319F	 # [14]
3200	321E	 # [31]
3220	3247	 # [40]
3250	327E	 # [47]
3280	32FE	 # [127]
3300	33FF	 # [256]
A770		
FB00	FB06	 # [7]
FB13	FB17	 # [5]
FB20	FB29	 # [10]
FB4F	FBB1	 # [99]
FBD3	FD3D	 # [363]
FD50	FD8F	 # [64]
FD92	FDC7	 # [54]
FDF0	FDFC	 # [13]
FE10	FE19	 # [10]
FE30	FE44	 # [21]
FE47	FE52	 # [12]
FE54	FE66	 # [19]
FE68	FE6B	 # [4]
FE70	FE72	 # [3]
FE74		
FE76	FEFC	 # [135]
FF01	FFBE	 # [190]
FFC2	FFC7	 # [6]
FFCA	FFCF	 # [6]
FFD2	FFD7	 # [6]
FFDA	FFDC	 # [3]
FFE0	FFE6	 # [7]
FFE8	FFEE	 # [7]
1D400	1D454	 # [85]
1D456	1D49C	 # [71]
1D49E	1D49F	 # [2]
1D4A2		
1D4A5	1D4A6	 # [2]
1D4A9	1D4AC	 # [4]
1D4AE	1D4B9	 # [12]
1D4BB		
1D4BD	1D4C3	 # [7]
1D4C5	1D505	 # [65]
1D507	1D50A	 # [4]
1D50D	1D514	 # [8]
1D516	1D51C	 # [7]
1D51E	1D539	 # [28]
1D53B	1D53E	 # [4]
1D540	1D544	 # [5]
1D546		
1D54A	1D550	 # [7]
1D552	1D6A5	 # [340]
1D6A8	1D7CB	 # [292]
1D7CE	1D7FF	 # [50]
1F100	1F10A	 # [11]
1F110	1F12E	 # [31]
1F131		
1F13D		
1F13F		
1F142		
1F146		
1F14A	1F14E	 # [5]
1F190		
1F200		
1F210	1F231	 # [34]
1F240	1F248	 # [9]
END
