# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 1_102_583 code points in Unicode Version 5.2.0 that
# match any of the following regular expression constructs:
# 
#         \p{Hangul_Syllable_Type=Not_Applicable}
#         \p{Hst=NA}
#         \p{Is_Hangul_Syllable_Type=Not_Applicable}
#         \p{Is_Hst=NA}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Hst: Not_Applicable}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0000	10FF	 # [4352]
1200	A95F	 # [38_752]
A97D	ABFF	 # [643]
D7A4	D7AF	 # [12]
D7C7	D7CA	 # [4]
D7FC	10FFFF	 # [1_058_820]
END
