# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 1043 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Decomposition_Type=Font}
#         \p{Dt=Font}
#         \p{Is_Decomposition_Type=Font}
#         \p{Is_Dt=Font}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Dt: Font}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
2102		
210A	2113	 # [10]
2115		
2119	211D	 # [5]
2124		
2128		
212C	212D	 # [2]
212F	2131	 # [3]
2133	2134	 # [2]
2139		
213C	2140	 # [5]
2145	2149	 # [5]
FB20	FB29	 # [10]
1D400	1D454	 # [85]
1D456	1D49C	 # [71]
1D49E	1D49F	 # [2]
1D4A2		
1D4A5	1D4A6	 # [2]
1D4A9	1D4AC	 # [4]
1D4AE	1D4B9	 # [12]
1D4BB		
1D4BD	1D4C3	 # [7]
1D4C5	1D505	 # [65]
1D507	1D50A	 # [4]
1D50D	1D514	 # [8]
1D516	1D51C	 # [7]
1D51E	1D539	 # [28]
1D53B	1D53E	 # [4]
1D540	1D544	 # [5]
1D546		
1D54A	1D550	 # [7]
1D552	1D6A5	 # [340]
1D6A8	1D7CB	 # [292]
1D7CE	1D7FF	 # [50]
END
