# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 1030 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Script=Arabic}
#         \p{Sc=Arab}
#         \p{Is_Script=Arabic}
#         \p{Is_Sc=Arab}
# 
#         \p{Arabic}
#         \p{Is_Arabic}
#         \p{Arab}
#         \p{Is_Arab}
# 
#     Note that contrary to what you might expect, the above is NOT the same
#     as \p{Block=Arabic}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Sc: Arabic}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0606	060B	 # [6]
060D	061A	 # [14]
061E		
0621	063F	 # [31]
0641	064A	 # [10]
0656	065E	 # [9]
066A	066F	 # [6]
0671	06DC	 # [108]
06DE	06FF	 # [34]
0750	077F	 # [48]
FB50	FBB1	 # [98]
FBD3	FD3D	 # [363]
FD50	FD8F	 # [64]
FD92	FDC7	 # [54]
FDF0	FDFC	 # [13]
FE70	FE74	 # [5]
FE76	FEFC	 # [135]
10E60	10E7E	 # [31]
END
