# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 1_113_473 code points in Unicode Version 5.2.0 that
# match any of the following regular expression constructs:
# 
#         \p{Diacritic=No}
#         \p{Dia=N}
#         \p{Is_Diacritic=F}
#         \p{Is_Dia=False}
# 
#         \P{Diacritic}
#         \P{Is_Diacritic}
#         \P{Dia}
#         \P{Is_Dia}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Dia: No}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0000	005D	 # [94]
005F		
0061	00A7	 # [71]
00A9	00AE	 # [6]
00B0	00B3	 # [4]
00B5	00B6	 # [2]
00B9	02AF	 # [503]
034F		
0358	035C	 # [5]
0363	0373	 # [17]
0376	0379	 # [4]
037B	0383	 # [9]
0386	0482	 # [253]
0488	0558	 # [209]
055A	0590	 # [55]
05A2		
05BE		
05C0		
05C3		
05C5	064A	 # [134]
0653	0656	 # [4]
0659	06DE	 # [134]
06E1	06E4	 # [4]
06E7	06E9	 # [3]
06ED	072F	 # [67]
074B	07A5	 # [91]
07B1	07EA	 # [58]
07F6	0817	 # [34]
081A	093B	 # [290]
093D	094C	 # [16]
094E	0950	 # [3]
0955	0970	 # [28]
0972	09BB	 # [74]
09BD	09CC	 # [16]
09CE	0A3B	 # [110]
0A3D	0A4C	 # [16]
0A4E	0ABB	 # [110]
0ABD	0ACC	 # [16]
0ACE	0B3B	 # [110]
0B3D	0B4C	 # [16]
0B4E	0BCC	 # [127]
0BCE	0C4C	 # [127]
0C4E	0CBB	 # [110]
0CBD	0CCC	 # [16]
0CCE	0D4C	 # [127]
0D4E	0DC9	 # [124]
0DCB	0E46	 # [124]
0E4D		
0E4F	0EC7	 # [121]
0ECD	0F17	 # [75]
0F1A	0F34	 # [27]
0F36		
0F38		
0F3A	0F3D	 # [4]
0F40	0F81	 # [66]
0F85		
0F88	0FC5	 # [62]
0FC7	1036	 # [112]
1038		
103B	1086	 # [76]
108E		
1090	1099	 # [10]
109C	17C8	 # [1837]
17D4	17DC	 # [9]
17DE	1938	 # [347]
193C	1A74	 # [313]
1A7D	1A7E	 # [2]
1A80	1B33	 # [180]
1B35	1B43	 # [15]
1B45	1B6A	 # [38]
1B74	1BA9	 # [54]
1BAB	1C35	 # [139]
1C38	1C77	 # [64]
1C7E	1CCF	 # [82]
1CE9	1CEC	 # [4]
1CEE	1D2B	 # [62]
1D6B	1DC3	 # [89]
1DD0	1DFC	 # [45]
1E00	1FBC	 # [445]
1FBE		
1FC2	1FCC	 # [11]
1FD0	1FDC	 # [13]
1FE0	1FEC	 # [13]
1FF0	1FFC	 # [13]
1FFF	2CEE	 # [3312]
2CF2	2E2E	 # [317]
2E30	3029	 # [506]
3030	3098	 # [105]
309D	30FB	 # [95]
30FD	A66E	 # [30_066]
A670	A67B	 # [12]
A67E		
A680	A6EF	 # [112]
A6F2	A716	 # [37]
A722	A787	 # [102]
A789	A8C3	 # [315]
A8C5	A8DF	 # [27]
A8F2	A92A	 # [57]
A92F	A952	 # [36]
A954	A9B2	 # [95]
A9B4	A9BF	 # [12]
A9C1	AA7A	 # [186]
AA7C	AABE	 # [67]
AAC3	ABEB	 # [297]
ABEE	FB1D	 # [20_272]
FB1F	FE1F	 # [769]
FE27	FF3D	 # [279]
FF3F		
FF41	FF6F	 # [47]
FF71	FF9D	 # [45]
FFA0	FFE2	 # [67]
FFE4	110B8	 # [4309]
110BB	1D166	 # [49_324]
1D16A	1D16C	 # [3]
1D173	1D17A	 # [8]
1D183	1D184	 # [2]
1D18C	1D1A9	 # [30]
1D1AE	10FFFF	 # [994_898]
END
