# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 1116 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Bidi_Class=Arabic_Letter}
#         \p{Bc=AL}
#         \p{Is_Bidi_Class=Arabic_Letter}
#         \p{Is_Bc=AL}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Bc: Arabic_Letter}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0604	0605	 # [2]
0608		
060B		
060D		
061B	064A	 # [48]
065F		
066D	066F	 # [3]
0671	06D5	 # [101]
06E5	06E6	 # [2]
06EE	06EF	 # [2]
06FA	070E	 # [21]
0710		
0712	072F	 # [30]
074B	07A5	 # [91]
07B1	07BF	 # [15]
FB50	FD3D	 # [494]
FD40	FDCF	 # [144]
FDF0	FDFC	 # [13]
FDFE	FDFF	 # [2]
FE70	FEFE	 # [143]
END
