#!/bin/sh
config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
config usr/lib/perl5/5.12.3/arm-linux-gnueabi-thread-multi/perllocal.pod.new
( cd usr/bin ; rm -rf psed )
( cd usr/bin ; ln -sf s2p psed )
( cd usr/bin ; rm -rf pstruct )
( cd usr/bin ; ln -sf c2ph pstruct )
( cd usr/bin ; rm -rf perl )
( cd usr/bin ; ln -sf perl5.12.3 perl )
( cd usr/man/man1 ; rm -rf psed.1.gz.gz )
( cd usr/man/man1 ; ln -sf s2p.1.gz.gz psed.1.gz.gz )
( cd usr/man/man1 ; rm -rf pstruct.1.gz.gz )
( cd usr/man/man1 ; ln -sf c2ph.1.gz.gz pstruct.1.gz.gz )
