# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 1273 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Age=4.1}
#         \p{Is_Age=4.1}
# 
#     Meaning: Code point's usage was introduced in version 4.1
# 
#     Note: See also Property 'Present_In'
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Age: 4.1}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0237	0241	 # [11]
0358	035C	 # [5]
03FC	03FF	 # [4]
04F6	04F7	 # [2]
05A2		
05C5	05C7	 # [3]
060B		
061E		
0659	065E	 # [6]
0750	076D	 # [30]
097D		
09CE		
0BB6		
0BE6		
0FD0	0FD1	 # [2]
10F9	10FA	 # [2]
10FC		
1207		
1247		
1287		
12AF		
12CF		
12EF		
130F		
131F		
1347		
135F	1360	 # [2]
1380	1399	 # [26]
1980	19A9	 # [42]
19B0	19C9	 # [26]
19D0	19D9	 # [10]
19DE	19DF	 # [2]
1A00	1A1B	 # [28]
1A1E	1A1F	 # [2]
1D6C	1DC3	 # [88]
2055	2056	 # [2]
2058	205E	 # [7]
2090	2094	 # [5]
20B2	20B5	 # [4]
20EB		
213C		
214C		
23D1	23DB	 # [11]
2618		
267E	267F	 # [2]
2692	269C	 # [11]
26A2	26B1	 # [16]
27C0	27C6	 # [7]
2B0E	2B13	 # [6]
2C00	2C2E	 # [47]
2C30	2C5E	 # [47]
2C80	2CEA	 # [107]
2CF9	2D25	 # [45]
2D30	2D65	 # [54]
2D6F		
2D80	2D96	 # [23]
2DA0	2DA6	 # [7]
2DA8	2DAE	 # [7]
2DB0	2DB6	 # [7]
2DB8	2DBE	 # [7]
2DC0	2DC6	 # [7]
2DC8	2DCE	 # [7]
2DD0	2DD6	 # [7]
2DD8	2DDE	 # [7]
2E00	2E17	 # [24]
2E1C	2E1D	 # [2]
31C0	31CF	 # [16]
327E		
9FA6	9FBB	 # [22]
A700	A716	 # [23]
A800	A82B	 # [44]
FA70	FAD9	 # [106]
FE10	FE19	 # [10]
10140	1018A	 # [75]
103A0	103C3	 # [36]
103C8	103D5	 # [14]
10A00	10A03	 # [4]
10A05	10A06	 # [2]
10A0C	10A13	 # [8]
10A15	10A17	 # [3]
10A19	10A33	 # [27]
10A38	10A3A	 # [3]
10A3F	10A47	 # [9]
10A50	10A58	 # [9]
1D200	1D245	 # [70]
1D6A4	1D6A5	 # [2]
END
