# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 87 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Numeric_Value=4}
#         \p{Nv=4}
#         \p{Is_Numeric_Value=4}
#         \p{Is_Nv=4}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Nv: 4}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0034		
0664		
06F4		
07C4		
096A		
09EA		
0A6A		
0AEA		
0B6A		
0BEA		
0C6A		
0CEA		
0D6A		
0E54		
0ED4		
0F24		
1044		
1094		
136C		
17E4		
17F4		
1814		
194A		
19D4		
1A84		
1A94		
1B54		
1BB4		
1C44		
1C54		
2074		
2084		
2163		
2173		
2463		
2477		
248B		
24F8		
2779		
2783		
278D		
3024		
3195		
3223		
3283		
4E96		
56DB		
8086		
A624		
A6E9		
A8D4		
A904		
A9D4		
AA54		
ABF4		
FF14		
1010A		
104A4		
10A43		
10B5B		
10B7B		
10E63		
12402		
12409		
1240F		
12418		
12421		
12426		
12430		
12438		
1243C	1243F	 # [4]
1244C		
12452	12453	 # [2]
1D363		
1D7D2		
1D7DC		
1D7E6		
1D7F0		
1D7FA		
1F105		
20064		
200E2		
2626D		
END
