# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 137 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Line_Break=Break_After}
#         \p{Lb=BA}
#         \p{Is_Line_Break=Break_After}
#         \p{Is_Lb=BA}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Lb: Break_After}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0009		
007C		
00AD		
058A		
05BE		
0964	0965	 # [2]
0E5A	0E5B	 # [2]
0F0B		
0F34		
0F7F		
0F85		
0FBE	0FBF	 # [2]
0FD2		
104A	104B	 # [2]
1361		
1400		
1680		
16EB	16ED	 # [3]
1735	1736	 # [2]
17D4	17D5	 # [2]
17D8		
17DA		
1804	1805	 # [2]
1B5A	1B5B	 # [2]
1B5D	1B60	 # [4]
1C3B	1C3F	 # [5]
1C7E	1C7F	 # [2]
2000	2006	 # [7]
2008	200A	 # [3]
2010		
2012	2013	 # [2]
2027		
2056		
2058	205B	 # [4]
205D	205F	 # [3]
2CFA	2CFC	 # [3]
2CFF		
2E0E	2E15	 # [8]
2E17		
2E19		
2E2A	2E2D	 # [4]
2E30	2E31	 # [2]
A4FE	A4FF	 # [2]
A60D		
A60F		
A6F3	A6F7	 # [5]
A8CE	A8CF	 # [2]
A92E	A92F	 # [2]
A9C7	A9C9	 # [3]
AA5D	AA5F	 # [3]
ABEB		
10100	10102	 # [3]
1039F		
103D0		
10857		
1091F		
10A50	10A57	 # [8]
10B39	10B3F	 # [7]
110BE	110C1	 # [4]
12470	12473	 # [4]
END
