# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 188 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Joining_Type=Dual_Joining}
#         \p{Jt=D}
#         \p{Is_Joining_Type=Dual_Joining}
#         \p{Is_Jt=D}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Jt: Dual_Joining}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0626		
0628		
062A	062E	 # [5]
0633	063F	 # [13]
0641	0647	 # [7]
0649	064A	 # [2]
066E	066F	 # [2]
0678	0687	 # [16]
069A	06BF	 # [38]
06C1	06C2	 # [2]
06CC		
06CE		
06D0	06D1	 # [2]
06FA	06FC	 # [3]
06FF		
0712	0714	 # [3]
071A	071D	 # [4]
071F	0727	 # [9]
0729		
072B		
072D	072E	 # [2]
074E	0758	 # [11]
075C	076A	 # [15]
076D	0770	 # [4]
0772		
0775	0777	 # [3]
077A	077F	 # [6]
07CA	07EA	 # [33]
END
