# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 55 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Numeric_Value=0}
#         \p{Nv=0}
#         \p{Is_Numeric_Value=0}
#         \p{Is_Nv=0}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Nv: 0}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0030		
0660		
06F0		
07C0		
0966		
09E6		
0A66		
0AE6		
0B66		
0BE6		
0C66		
0C78		
0CE6		
0D66		
0E50		
0ED0		
0F20		
1040		
1090		
17E0		
17F0		
1810		
1946		
19D0		
1A80		
1A90		
1B50		
1BB0		
1C40		
1C50		
2070		
2080		
2189		
24EA		
24FF		
3007		
96F6		
A620		
A6EF		
A8D0		
A900		
A9D0		
AA50		
ABF0		
F9B2		
FF10		
1018A		
104A0		
1D7CE		
1D7D8		
1D7E2		
1D7EC		
1D7F6		
1F100	1F101	 # [2]
END
