# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 161 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Terminal_Punctuation=Yes}
#         \p{Term=Y}
#         \p{Is_Terminal_Punctuation=T}
#         \p{Is_Term=True}
# 
#         \p{Terminal_Punctuation}
#         \p{Is_Terminal_Punctuation}
#         \p{Term}
#         \p{Is_Term}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Term: Yes}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0021		
002C		
002E		
003A	003B	 # [2]
003F		
037E		
0387		
0589		
05C3		
060C		
061B		
061F		
06D4		
0700	070A	 # [11]
070C		
07F8	07F9	 # [2]
0830	083E	 # [15]
0964	0965	 # [2]
0E5A	0E5B	 # [2]
0F08		
0F0D	0F12	 # [6]
104A	104B	 # [2]
1361	1368	 # [8]
166D	166E	 # [2]
16EB	16ED	 # [3]
17D4	17D6	 # [3]
17DA		
1802	1805	 # [4]
1808	1809	 # [2]
1944	1945	 # [2]
1AA8	1AAB	 # [4]
1B5A	1B5B	 # [2]
1B5D	1B5F	 # [3]
1C3B	1C3F	 # [5]
1C7E	1C7F	 # [2]
203C	203D	 # [2]
2047	2049	 # [3]
2E2E		
3001	3002	 # [2]
A4FE	A4FF	 # [2]
A60D	A60F	 # [3]
A6F3	A6F7	 # [5]
A876	A877	 # [2]
A8CE	A8CF	 # [2]
A92F		
A9C7	A9C9	 # [3]
AA5D	AA5F	 # [3]
AADF		
ABEB		
FE50	FE52	 # [3]
FE54	FE57	 # [4]
FF01		
FF0C		
FF0E		
FF1A	FF1B	 # [2]
FF1F		
FF61		
FF64		
1039F		
103D0		
10857		
1091F		
10B3A	10B3F	 # [6]
110BE	110C1	 # [4]
12470	12473	 # [4]
END
