# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 1_110_704 code points in Unicode Version 5.2.0 that
# match any of the following regular expression constructs:
# 
#         \p{Cased=No}
#         \p{Is_Cased=N}
#         \p{Cased=F}
#         \p{Is_Cased=False}
# 
#         \P{Cased}
#         \P{Is_Cased}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Cased: No}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0000	0040	 # [65]
005B	0060	 # [6]
007B	00A9	 # [47]
00AB	00B4	 # [10]
00B6	00B9	 # [4]
00BB	00BF	 # [5]
00D7		
00F7		
01BB		
01C0	01C3	 # [4]
0294		
02B9	02BF	 # [7]
02C2	02DF	 # [30]
02E5	0344	 # [96]
0346	036F	 # [42]
0374	0375	 # [2]
0378	0379	 # [2]
037E	0385	 # [8]
0387		
038B		
038D		
03A2		
03F6		
0482	0489	 # [8]
0526	0530	 # [11]
0557	0560	 # [10]
0588	109F	 # [2840]
10C6	1CFF	 # [3130]
1DC0	1DFF	 # [64]
1F16	1F17	 # [2]
1F1E	1F1F	 # [2]
1F46	1F47	 # [2]
1F4E	1F4F	 # [2]
1F58		
1F5A		
1F5C		
1F5E		
1F7E	1F7F	 # [2]
1FB5		
1FBD		
1FBF	1FC1	 # [3]
1FC5		
1FCD	1FCF	 # [3]
1FD4	1FD5	 # [2]
1FDC	1FDF	 # [4]
1FED	1FF1	 # [5]
1FF5		
1FFD	208F	 # [147]
2095	2101	 # [109]
2103	2106	 # [4]
2108	2109	 # [2]
2114		
2116	2118	 # [3]
211E	2123	 # [6]
2125		
2127		
2129		
212E		
2135	2138	 # [4]
213A	213B	 # [2]
2140	2144	 # [5]
214A	214D	 # [4]
214F	215F	 # [17]
2180	2182	 # [3]
2185	24B5	 # [817]
24EA	2BFF	 # [1814]
2C2F		
2C5F		
2CE5	2CEA	 # [6]
2CEF	2CFF	 # [17]
2D26	A63F	 # [31_002]
A660	A661	 # [2]
A66E	A67F	 # [18]
A698	A721	 # [138]
A788	A78A	 # [3]
A78D	FAFF	 # [21_363]
FB07	FB12	 # [12]
FB18	FF20	 # [1033]
FF3B	FF40	 # [6]
FF5B	103FF	 # [1189]
10450	1D3FF	 # [53_168]
1D455		
1D49D		
1D4A0	1D4A1	 # [2]
1D4A3	1D4A4	 # [2]
1D4A7	1D4A8	 # [2]
1D4AD		
1D4BA		
1D4BC		
1D4C4		
1D506		
1D50B	1D50C	 # [2]
1D515		
1D51D		
1D53A		
1D53F		
1D545		
1D547	1D549	 # [3]
1D551		
1D6A6	1D6A7	 # [2]
1D6C1		
1D6DB		
1D6FB		
1D715		
1D735		
1D74F		
1D76F		
1D789		
1D7A9		
1D7C3		
1D7CC	10FFFF	 # [993_332]
END
