# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 1_112_994 code points in Unicode Version 5.2.0 that
# match any of the following regular expression constructs:
# 
#         \p{Full_Composition_Exclusion=No}
#         \p{Comp_Ex=N}
#         \p{Is_Full_Composition_Exclusion=F}
#         \p{Is_Comp_Ex=False}
# 
#         \P{Full_Composition_Exclusion}
#         \P{Is_Full_Composition_Exclusion}
#         \P{Comp_Ex}
#         \P{Is_Comp_Ex}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Comp_Ex: No}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0000	033F	 # [832]
0342		
0345	0373	 # [47]
0375	037D	 # [9]
037F	0386	 # [8]
0388	0957	 # [1488]
0960	09DB	 # [124]
09DE		
09E0	0A32	 # [83]
0A34	0A35	 # [2]
0A37	0A58	 # [34]
0A5C	0A5D	 # [2]
0A5F	0B5B	 # [253]
0B5E	0F42	 # [997]
0F44	0F4C	 # [9]
0F4E	0F51	 # [4]
0F53	0F56	 # [4]
0F58	0F5B	 # [4]
0F5D	0F68	 # [12]
0F6A	0F72	 # [9]
0F74		
0F77		
0F79	0F80	 # [8]
0F82	0F92	 # [17]
0F94	0F9C	 # [9]
0F9E	0FA1	 # [4]
0FA3	0FA6	 # [4]
0FA8	0FAB	 # [4]
0FAD	0FB8	 # [12]
0FBA	1F70	 # [4023]
1F72		
1F74		
1F76		
1F78		
1F7A		
1F7C		
1F7E	1FBA	 # [61]
1FBC	1FBD	 # [2]
1FBF	1FC8	 # [10]
1FCA		
1FCC	1FD2	 # [7]
1FD4	1FDA	 # [7]
1FDC	1FE2	 # [7]
1FE4	1FEA	 # [7]
1FEC	1FED	 # [2]
1FF0	1FF8	 # [9]
1FFA		
1FFC		
1FFE	1FFF	 # [2]
2002	2125	 # [292]
2127	2129	 # [3]
212C	2328	 # [509]
232B	2ADB	 # [1969]
2ADD	F8FF	 # [52_771]
FA0E	FA0F	 # [2]
FA11		
FA13	FA14	 # [2]
FA1F		
FA21		
FA23	FA24	 # [2]
FA27	FA29	 # [3]
FA2E	FA2F	 # [2]
FA6E	FA6F	 # [2]
FADA	FB1C	 # [67]
FB1E		
FB20	FB29	 # [10]
FB37		
FB3D		
FB3F		
FB42		
FB45		
FB4F	1D15D	 # [54_799]
1D165	1D1BA	 # [86]
1D1C1	2F7FF	 # [75_327]
2FA1E	10FFFF	 # [919_010]
END
