# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 117 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Canonical_Combining_Class=Below}
#         \p{Ccc=B}
#         \p{Is_Canonical_Combining_Class=220}
#         \p{Is_Ccc=Below}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Ccc: Below}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0316	0319	 # [4]
031C	0320	 # [5]
0323	0326	 # [4]
0329	0333	 # [11]
0339	033C	 # [4]
0347	0349	 # [3]
034D	034E	 # [2]
0353	0356	 # [4]
0359	035A	 # [2]
0591		
0596		
059B		
05A2	05A7	 # [6]
05AA		
05C5		
0655	0656	 # [2]
065C		
06E3		
06EA		
06ED		
0731		
0734		
0737	0739	 # [3]
073B	073C	 # [2]
073E		
0742		
0744		
0746		
0748		
07F2		
0952		
0F18	0F19	 # [2]
0F35		
0F37		
0FC6		
108D		
193B		
1A18		
1A7F		
1B6C		
1CD5	1CD9	 # [5]
1CDC	1CDF	 # [4]
1CED		
1DC2		
1DCA		
1DCF		
1DFD		
1DFF		
20E8		
20EC	20EF	 # [4]
A92B	A92D	 # [3]
AAB4		
101FD		
10A0D		
10A3A		
1D17B	1D182	 # [8]
1D18A	1D18B	 # [2]
END
