# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 612 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Numeric_Type=Numeric}
#         \p{Nt=Nu}
#         \p{Is_Numeric_Type=Numeric}
#         \p{Is_Nt=Nu}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Nt: Numeric}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
00BC	00BE	 # [3]
09F4	09F9	 # [6]
0BF0	0BF2	 # [3]
0C78	0C7E	 # [7]
0D70	0D75	 # [6]
0F2A	0F33	 # [10]
1372	137C	 # [11]
16EE	16F0	 # [3]
17F0	17F9	 # [10]
2150	2182	 # [51]
2185	2189	 # [5]
2469	2473	 # [11]
247D	2487	 # [11]
2491	249B	 # [11]
24EB	24F4	 # [10]
24FE		
277F		
2789		
2793		
2CFD		
3007		
3021	3029	 # [9]
3038	303A	 # [3]
3192	3195	 # [4]
3220	3229	 # [10]
3251	325F	 # [15]
3280	3289	 # [10]
32B1	32BF	 # [15]
3405		
3483		
382A		
3B4D		
4E00		
4E03		
4E07		
4E09		
4E5D		
4E8C		
4E94		
4E96		
4EBF	4EC0	 # [2]
4EDF		
4EE8		
4F0D		
4F70		
5104		
5146		
5169		
516B		
516D		
5341		
5343	5345	 # [3]
534C		
53C1	53C4	 # [4]
56DB		
58F1		
58F9		
5E7A		
5EFE	5EFF	 # [2]
5F0C	5F0E	 # [3]
5F10		
62FE		
634C		
67D2		
6F06		
7396		
767E		
8086		
842C		
8CAE		
8CB3		
8D30		
9621		
9646		
964C		
9678		
96F6		
A6E6	A6EF	 # [10]
A830	A835	 # [6]
F96B		
F973		
F978		
F9B2		
F9D1		
F9D3		
F9FD		
10107	10133	 # [45]
10140	10178	 # [57]
1018A		
10320	10323	 # [4]
10341		
1034A		
103D1	103D5	 # [5]
10858	1085F	 # [8]
10916	1091B	 # [6]
10A44	10A47	 # [4]
10A7D	10A7E	 # [2]
10B58	10B5F	 # [8]
10B78	10B7F	 # [8]
10E69	10E7E	 # [22]
12400	12431	 # [50]
12434	12455	 # [34]
12458	12462	 # [11]
1D360	1D371	 # [18]
20001		
20064		
200E2		
20121		
2092A		
20983		
2098C		
2099C		
20AEA		
20AFD		
20B19		
22390		
22998		
23B1B		
2626D		
2F890		
END
