# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 1_113_907 code points in Unicode Version 5.2.0 that
# match:
# 
#         \p{_X_Begin}
# 
# perluniprops.pod should be consulted for the syntax rules for this,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# For use in \X; matches: Hangul_Syllable | ! Control
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0020	007E	 # [95]
00A0	00AC	 # [13]
00AE	05FF	 # [1362]
0604	06DC	 # [217]
06DE	070E	 # [49]
0710	17B3	 # [4260]
17B6	200A	 # [2133]
200C	200D	 # [2]
2010	2027	 # [24]
202F	205F	 # [49]
2065	2069	 # [5]
2070	FEFE	 # [56_975]
FF00	FFF8	 # [249]
FFFC	110BC	 # [4289]
110BE	1D172	 # [49_333]
1D17B	E0000	 # [798_342]
E0002	E001F	 # [30]
E0080	10FFFF	 # [196_480]
END
