# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 2110 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Changes_When_Casemapped=Yes}
#         \p{CWCM=Y}
#         \p{Is_Changes_When_Casemapped=T}
#         \p{Is_CWCM=True}
# 
#         \p{Changes_When_Casemapped}
#         \p{Is_Changes_When_Casemapped}
#         \p{CWCM}
#         \p{Is_CWCM}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_CWCM: Yes}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0041	005A	 # [26]
0061	007A	 # [26]
00B5		
00C0	00D6	 # [23]
00D8	00F6	 # [31]
00F8	0137	 # [64]
0139	018C	 # [84]
018E	019A	 # [13]
019C	01A9	 # [14]
01AC	01B9	 # [14]
01BC	01BD	 # [2]
01BF		
01C4	0220	 # [93]
0222	0233	 # [18]
023A	0254	 # [27]
0256	0257	 # [2]
0259		
025B		
0260		
0263		
0268	0269	 # [2]
026B		
026F		
0271	0272	 # [2]
0275		
027D		
0280		
0283		
0288	028C	 # [5]
0292		
0345		
0370	0373	 # [4]
0376	0377	 # [2]
037B	037D	 # [3]
0386		
0388	038A	 # [3]
038C		
038E	03A1	 # [20]
03A3	03D1	 # [47]
03D5	03F2	 # [30]
03F4	03F5	 # [2]
03F7	03FB	 # [5]
03FD	0481	 # [133]
048A	0525	 # [156]
0531	0556	 # [38]
0561	0587	 # [39]
10A0	10C5	 # [38]
1D79		
1D7D		
1E00	1E9B	 # [156]
1E9E		
1EA0	1F15	 # [118]
1F18	1F1D	 # [6]
1F20	1F45	 # [38]
1F48	1F4D	 # [6]
1F50	1F57	 # [8]
1F59		
1F5B		
1F5D		
1F5F	1F7D	 # [31]
1F80	1FB4	 # [53]
1FB6	1FBC	 # [7]
1FBE		
1FC2	1FC4	 # [3]
1FC6	1FCC	 # [7]
1FD0	1FD3	 # [4]
1FD6	1FDB	 # [6]
1FE0	1FEC	 # [13]
1FF2	1FF4	 # [3]
1FF6	1FFC	 # [7]
2126		
212A	212B	 # [2]
2132		
214E		
2160	217F	 # [32]
2183	2184	 # [2]
24B6	24E9	 # [52]
2C00	2C2E	 # [47]
2C30	2C5E	 # [47]
2C60	2C70	 # [17]
2C72	2C73	 # [2]
2C75	2C76	 # [2]
2C7E	2CE3	 # [102]
2CEB	2CEE	 # [4]
2D00	2D25	 # [38]
A640	A65F	 # [32]
A662	A66D	 # [12]
A680	A697	 # [24]
A722	A72F	 # [14]
A732	A76F	 # [62]
A779	A787	 # [15]
A78B	A78C	 # [2]
FB00	FB06	 # [7]
FB13	FB17	 # [5]
FF21	FF3A	 # [26]
FF41	FF5A	 # [26]
10400	1044F	 # [80]
END
