# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# 'D' below means that this form is deprecated.  Consult perluniprops.pod
# 
# This file returns the 1_112_896 code points in Unicode Version 5.2.0 that
# match any of the following regular expression constructs:
# 
# D       \p{Other_Math=No}
# D       \p{OMath=N}
# D       \p{Is_Other_Math=F}
# D       \p{Is_OMath=False}
# 
# D       \P{Other_Math}
# D       \P{Is_Other_Math}
# D       \P{OMath}
# D       \P{Is_OMath}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_OMath: No}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0000	005D	 # [94]
005F	03CF	 # [881]
03D3	03D4	 # [2]
03D6	03EF	 # [26]
03F2	03F3	 # [2]
03F6	2015	 # [7200]
2017	2031	 # [27]
2035	203F	 # [11]
2041	2060	 # [32]
2065	207C	 # [24]
207F	208C	 # [14]
208F	20CF	 # [65]
20DD	20E0	 # [4]
20E2	20E4	 # [3]
20E7	20EA	 # [4]
20F0	2101	 # [18]
2103	2109	 # [7]
2114		
2116	2118	 # [3]
211E	2123	 # [6]
2125	2127	 # [3]
212A	212B	 # [2]
212E		
2132		
2139	213B	 # [3]
2140	2144	 # [5]
214A	2194	 # [75]
219A	219B	 # [2]
21A0		
21A3		
21A6		
21A8		
21AE	21AF	 # [2]
21B2	21B5	 # [4]
21B8	21BB	 # [4]
21CE	21CF	 # [2]
21D2		
21D4		
21DC		
21DE	21E3	 # [6]
21E6	23B3	 # [462]
23B6		
23B8	23CF	 # [24]
23D1	23E1	 # [17]
23E3	259F	 # [445]
25A2	25AD	 # [12]
25B7	25BB	 # [5]
25C1	25C5	 # [5]
25C8	25C9	 # [2]
25CC	25CE	 # [3]
25D4	25E1	 # [14]
25E3		
25E5	25E6	 # [2]
25ED	2604	 # [24]
2607	263F	 # [57]
2641		
2643	265F	 # [29]
2664	266C	 # [9]
266F	27C4	 # [342]
27C7	27E5	 # [31]
27F0	2982	 # [403]
2999	29D7	 # [63]
29DC	29FB	 # [32]
29FE	FE60	 # [54_371]
FE62		
FE64	FE67	 # [4]
FE69	FF3B	 # [211]
FF3D		
FF3F	1D3FF	 # [54_465]
1D455		
1D49D		
1D4A0	1D4A1	 # [2]
1D4A3	1D4A4	 # [2]
1D4A7	1D4A8	 # [2]
1D4AD		
1D4BA		
1D4BC		
1D4C4		
1D506		
1D50B	1D50C	 # [2]
1D515		
1D51D		
1D53A		
1D53F		
1D545		
1D547	1D549	 # [3]
1D551		
1D6A6	1D6A7	 # [2]
1D6C1		
1D6DB		
1D6FB		
1D715		
1D735		
1D74F		
1D76F		
1D789		
1D7A9		
1D7C3		
1D7CC	1D7CD	 # [2]
1D800	10FFFF	 # [993_280]
END
