# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 81 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Line_Break=Open_Punctuation}
#         \p{Lb=OP}
#         \p{Is_Line_Break=Open_Punctuation}
#         \p{Is_Lb=OP}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Lb: Open_Punctuation}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0028		
005B		
007B		
00A1		
00BF		
0F3A		
0F3C		
169B		
201A		
201E		
2045		
207D		
208D		
2329		
2768		
276A		
276C		
276E		
2770		
2772		
2774		
27C5		
27E6		
27E8		
27EA		
27EC		
27EE		
2983		
2985		
2987		
2989		
298B		
298D		
298F		
2991		
2993		
2995		
2997		
29D8		
29DA		
29FC		
2E18		
2E22		
2E24		
2E26		
2E28		
3008		
300A		
300C		
300E		
3010		
3014		
3016		
3018		
301A		
301D		
FD3E		
FE17		
FE35		
FE37		
FE39		
FE3B		
FE3D		
FE3F		
FE41		
FE43		
FE47		
FE59		
FE5B		
FE5D		
FF08		
FF3B		
FF5B		
FF5F		
FF62		
13258	1325A	 # [3]
13286		
13288		
13379		
END
