# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# 'D' below means that this form is deprecated.  Consult perluniprops.pod
# 
# This file returns the 759 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
# D       \p{Other_Alphabetic=Yes}
# D       \p{OAlpha=Y}
# D       \p{Is_Other_Alphabetic=T}
# D       \p{Is_OAlpha=True}
# 
# D       \p{Other_Alphabetic}
# D       \p{Is_Other_Alphabetic}
# D       \p{OAlpha}
# D       \p{Is_OAlpha}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_OAlpha: Yes}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0345		
05B0	05BD	 # [14]
05BF		
05C1	05C2	 # [2]
05C4	05C5	 # [2]
05C7		
0610	061A	 # [11]
064B	0657	 # [13]
0659	065E	 # [6]
0670		
06D6	06DC	 # [7]
06E1	06E4	 # [4]
06E7	06E8	 # [2]
06ED		
0711		
0730	073F	 # [16]
07A6	07B0	 # [11]
0816	0817	 # [2]
081B	0823	 # [9]
0825	0827	 # [3]
0829	082C	 # [4]
0900	0903	 # [4]
093E	094C	 # [15]
094E		
0955		
0962	0963	 # [2]
0981	0983	 # [3]
09BE	09C4	 # [7]
09C7	09C8	 # [2]
09CB	09CC	 # [2]
09D7		
09E2	09E3	 # [2]
0A01	0A03	 # [3]
0A3E	0A42	 # [5]
0A47	0A48	 # [2]
0A4B	0A4C	 # [2]
0A51		
0A70	0A71	 # [2]
0A75		
0A81	0A83	 # [3]
0ABE	0AC5	 # [8]
0AC7	0AC9	 # [3]
0ACB	0ACC	 # [2]
0AE2	0AE3	 # [2]
0B01	0B03	 # [3]
0B3E	0B44	 # [7]
0B47	0B48	 # [2]
0B4B	0B4C	 # [2]
0B56	0B57	 # [2]
0B62	0B63	 # [2]
0B82		
0BBE	0BC2	 # [5]
0BC6	0BC8	 # [3]
0BCA	0BCC	 # [3]
0BD7		
0C01	0C03	 # [3]
0C3E	0C44	 # [7]
0C46	0C48	 # [3]
0C4A	0C4C	 # [3]
0C55	0C56	 # [2]
0C62	0C63	 # [2]
0C82	0C83	 # [2]
0CBE	0CC4	 # [7]
0CC6	0CC8	 # [3]
0CCA	0CCC	 # [3]
0CD5	0CD6	 # [2]
0CE2	0CE3	 # [2]
0D02	0D03	 # [2]
0D3E	0D44	 # [7]
0D46	0D48	 # [3]
0D4A	0D4C	 # [3]
0D57		
0D62	0D63	 # [2]
0D82	0D83	 # [2]
0DCF	0DD4	 # [6]
0DD6		
0DD8	0DDF	 # [8]
0DF2	0DF3	 # [2]
0E31		
0E34	0E3A	 # [7]
0E4D		
0EB1		
0EB4	0EB9	 # [6]
0EBB	0EBC	 # [2]
0ECD		
0F71	0F81	 # [17]
0F90	0F97	 # [8]
0F99	0FBC	 # [36]
102B	1036	 # [12]
1038		
103B	103E	 # [4]
1056	1059	 # [4]
105E	1060	 # [3]
1062		
1067	1068	 # [2]
1071	1074	 # [4]
1082	1086	 # [5]
109C	109D	 # [2]
135F		
1712	1713	 # [2]
1732	1733	 # [2]
1752	1753	 # [2]
1772	1773	 # [2]
17B6	17C8	 # [19]
18A9		
1920	192B	 # [12]
1930	1938	 # [9]
19B0	19C0	 # [17]
19C8	19C9	 # [2]
1A17	1A1B	 # [5]
1A55	1A5E	 # [10]
1A61	1A74	 # [20]
1B00	1B04	 # [5]
1B35	1B43	 # [15]
1B80	1B82	 # [3]
1BA1	1BA9	 # [9]
1C24	1C35	 # [18]
1CF2		
24B6	24E9	 # [52]
2DE0	2DFF	 # [32]
A823	A827	 # [5]
A880	A881	 # [2]
A8B4	A8C3	 # [16]
A926	A92A	 # [5]
A947	A952	 # [12]
A980	A983	 # [4]
A9B3	A9BF	 # [13]
AA29	AA36	 # [14]
AA43		
AA4C	AA4D	 # [2]
AAB0		
AAB2	AAB4	 # [3]
AAB7	AAB8	 # [2]
AABE		
ABE3	ABEA	 # [8]
FB1E		
10A01	10A03	 # [3]
10A05	10A06	 # [2]
10A0C	10A0F	 # [4]
11082		
110B0	110B8	 # [9]
END
