# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 173_199 code points in Unicode Version 5.2.0 that
# match any of the following regular expression constructs:
# 
#         \p{East_Asian_Width=Wide}
#         \p{Ea=W}
#         \p{Is_East_Asian_Width=Wide}
#         \p{Is_Ea=W}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Ea: Wide}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
1100	115F	 # [96]
11A3	11A7	 # [5]
11FA	11FF	 # [6]
2329	232A	 # [2]
2E80	2E99	 # [26]
2E9B	2EF3	 # [89]
2F00	2FD5	 # [214]
2FF0	2FFB	 # [12]
3001	303E	 # [62]
3041	3096	 # [86]
3099	30FF	 # [103]
3105	312D	 # [41]
3131	318E	 # [94]
3190	31B7	 # [40]
31C0	31E3	 # [36]
31F0	321E	 # [47]
3220	3247	 # [40]
3250	32FE	 # [175]
3300	4DBF	 # [6848]
4E00	A48C	 # [22_157]
A490	A4C6	 # [55]
A960	A97C	 # [29]
AC00	D7A3	 # [11_172]
D7B0	D7C6	 # [23]
D7CB	D7FB	 # [49]
F900	FAFF	 # [512]
FE10	FE19	 # [10]
FE30	FE52	 # [35]
FE54	FE66	 # [19]
FE68	FE6B	 # [4]
1F200		
1F210	1F231	 # [34]
1F240	1F248	 # [9]
20000	2FFFD	 # [65_534]
30000	3FFFD	 # [65_534]
END
