# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 91 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Numeric_Value=1}
#         \p{Nv=1}
#         \p{Is_Numeric_Value=1}
#         \p{Is_Nv=1}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Nv: 1}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0031		
00B9		
0661		
06F1		
07C1		
0967		
09E7		
0A67		
0AE7		
0B67		
0BE7		
0C67		
0C79		
0C7C		
0CE7		
0D67		
0E51		
0ED1		
0F21		
1041		
1091		
1369		
17E1		
17F1		
1811		
1947		
19D1		
19DA		
1A81		
1A91		
1B51		
1BB1		
1C41		
1C51		
2081		
215F	2160	 # [2]
2170		
2460		
2474		
2488		
24F5		
2776		
2780		
278A		
3021		
3192		
3220		
3280		
4E00		
58F1		
58F9		
5E7A		
5F0C		
A621		
A6E6		
A8D1		
A901		
A9D1		
AA51		
ABF1		
FF11		
10107		
10142		
10158	1015A	 # [3]
10320		
103D1		
104A1		
10858		
10916		
10A40		
10A7D		
10B58		
10B78		
10E60		
12415		
1241E		
1242C		
12434		
1244F		
12458		
1D360		
1D7CF		
1D7D9		
1D7E3		
1D7ED		
1D7F7		
1F102		
2092A		
END
