# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 63 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Sentence_Break=STerm}
#         \p{SB=ST}
#         \p{Is_Sentence_Break=STerm}
#         \p{Is_SB=ST}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_SB: STerm}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0021		
003F		
055C		
055E		
0589		
061F		
06D4		
0700	0702	 # [3]
07F9		
0964	0965	 # [2]
104A	104B	 # [2]
1362		
1367	1368	 # [2]
166E		
1803		
1809		
1944	1945	 # [2]
1B5A	1B5B	 # [2]
1B5E	1B5F	 # [2]
1C3B	1C3C	 # [2]
1C7E	1C7F	 # [2]
203C	203D	 # [2]
2047	2049	 # [3]
2E2E		
3002		
A4FF		
A60E	A60F	 # [2]
A6F3		
A6F7		
A876	A877	 # [2]
A8CE	A8CF	 # [2]
A92F		
A9C8	A9C9	 # [2]
AA5D	AA5F	 # [3]
ABEB		
FE56	FE57	 # [2]
FF01		
FF1F		
FF61		
110BE	110C1	 # [4]
END
