# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 1_113_518 code points in Unicode Version 5.2.0 that
# match any of the following regular expression constructs:
# 
#         \p{Canonical_Combining_Class=Not_Reordered}
#         \p{Ccc=NR}
#         \p{Is_Canonical_Combining_Class=0}
#         \p{Is_Ccc=Not_Reordered}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Ccc: Not_Reordered}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0000	02FF	 # [768]
034F		
0370	0482	 # [275]
0488	0590	 # [265]
05BE		
05C0		
05C3		
05C6		
05C8	060F	 # [72]
061B	064A	 # [48]
065F	066F	 # [17]
0671	06D5	 # [101]
06DD	06DE	 # [2]
06E5	06E6	 # [2]
06E9		
06EE	0710	 # [35]
0712	072F	 # [30]
074B	07EA	 # [160]
07F4	0815	 # [34]
081A		
0824		
0828		
082E	093B	 # [270]
093D	094C	 # [16]
094E	0950	 # [3]
0955	09BB	 # [103]
09BD	09CC	 # [16]
09CE	0A3B	 # [110]
0A3D	0A4C	 # [16]
0A4E	0ABB	 # [110]
0ABD	0ACC	 # [16]
0ACE	0B3B	 # [110]
0B3D	0B4C	 # [16]
0B4E	0BCC	 # [127]
0BCE	0C4C	 # [127]
0C4E	0C54	 # [7]
0C57	0CBB	 # [101]
0CBD	0CCC	 # [16]
0CCE	0D4C	 # [127]
0D4E	0DC9	 # [124]
0DCB	0E37	 # [109]
0E3B	0E47	 # [13]
0E4C	0EB7	 # [108]
0EBA	0EC7	 # [14]
0ECC	0F17	 # [76]
0F1A	0F34	 # [27]
0F36		
0F38		
0F3A	0F70	 # [55]
0F73		
0F75	0F79	 # [5]
0F7E	0F7F	 # [2]
0F81		
0F85		
0F88	0FC5	 # [62]
0FC7	1036	 # [112]
1038		
103B	108C	 # [82]
108E	135E	 # [721]
1360	1713	 # [948]
1715	1733	 # [31]
1735	17D1	 # [157]
17D3	17DC	 # [10]
17DE	18A8	 # [203]
18AA	1938	 # [143]
193C	1A16	 # [219]
1A19	1A5F	 # [71]
1A61	1A74	 # [20]
1A7D	1A7E	 # [2]
1A80	1B33	 # [180]
1B35	1B43	 # [15]
1B45	1B6A	 # [38]
1B74	1BA9	 # [54]
1BAB	1C36	 # [140]
1C38	1CCF	 # [152]
1CD3		
1CE1		
1CE9	1CEC	 # [4]
1CEE	1DBF	 # [210]
1DE7	1DFC	 # [22]
1E00	20CF	 # [720]
20DD	20E0	 # [4]
20E2	20E4	 # [3]
20F1	2CEE	 # [3070]
2CF2	2DDF	 # [238]
2E00	3029	 # [554]
3030	3098	 # [105]
309B	A66E	 # [30_164]
A670	A67B	 # [12]
A67E	A6EF	 # [114]
A6F2	A805	 # [276]
A807	A8C3	 # [189]
A8C5	A8DF	 # [27]
A8F2	A92A	 # [57]
A92E	A952	 # [37]
A954	A9B2	 # [95]
A9B4	A9BF	 # [12]
A9C1	AAAF	 # [239]
AAB1		
AAB5	AAB6	 # [2]
AAB9	AABD	 # [5]
AAC0		
AAC2	ABEC	 # [299]
ABEE	FB1D	 # [20_272]
FB1F	FE1F	 # [769]
FE27	101FC	 # [982]
101FE	10A0C	 # [2063]
10A0E		
10A10	10A37	 # [40]
10A3B	10A3E	 # [4]
10A40	110B8	 # [1657]
110BB	1D164	 # [49_322]
1D16A	1D16C	 # [3]
1D173	1D17A	 # [8]
1D183	1D184	 # [2]
1D18C	1D1A9	 # [30]
1D1AE	1D241	 # [148]
1D245	10FFFF	 # [994_747]
END
