# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file is for tables that are not necessarily related:  To conserve
# resources, every table that matches the identical set of code points in
# this version of Unicode uses this file.  Each one is listed in a separate
# group below.  It could be that the tables will match the same set of code
# points in other Unicode releases, or it could be purely coincidence that
# they happen to be the same in Unicode 5.2.0, and hence may not in other
# versions.
# 
# This file returns the 13_221 code points in Unicode Version 5.2.0 that
# match any of the following regular expression constructs:
# 
#         \p{NFD_Quick_Check=No}
#         \p{NFD_QC=N}
#         \p{Is_NFD_Quick_Check=No}
#         \p{Is_NFD_QC=N}
# 
#     Note that contrary to what you might expect, the above is NOT the same
#     as any of: \P{NFD_Quick_Check}, \P{NFD_QC}, \P{Is_NFD_Quick_Check},
#     \P{Is_NFD_QC}
# 
#         \p{Decomposition_Type=Canonical}
#         \p{Dt=Can}
#         \p{Is_Decomposition_Type=Canonical}
#         \p{Is_Dt=Can}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and within each group
# above, anything to the left of the equals (or colon) can be combined with
# anything to the right.  Thus, for example,
#         \p{Is_Dt: Canonical}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
00C0	00C5	 # [6]
00C7	00CF	 # [9]
00D1	00D6	 # [6]
00D9	00DD	 # [5]
00E0	00E5	 # [6]
00E7	00EF	 # [9]
00F1	00F6	 # [6]
00F9	00FD	 # [5]
00FF	010F	 # [17]
0112	0125	 # [20]
0128	0130	 # [9]
0134	0137	 # [4]
0139	013E	 # [6]
0143	0148	 # [6]
014C	0151	 # [6]
0154	0165	 # [18]
0168	017E	 # [23]
01A0	01A1	 # [2]
01AF	01B0	 # [2]
01CD	01DC	 # [16]
01DE	01E3	 # [6]
01E6	01F0	 # [11]
01F4	01F5	 # [2]
01F8	021B	 # [36]
021E	021F	 # [2]
0226	0233	 # [14]
0340	0341	 # [2]
0343	0344	 # [2]
0374		
037E		
0385	038A	 # [6]
038C		
038E	0390	 # [3]
03AA	03B0	 # [7]
03CA	03CE	 # [5]
03D3	03D4	 # [2]
0400	0401	 # [2]
0403		
0407		
040C	040E	 # [3]
0419		
0439		
0450	0451	 # [2]
0453		
0457		
045C	045E	 # [3]
0476	0477	 # [2]
04C1	04C2	 # [2]
04D0	04D3	 # [4]
04D6	04D7	 # [2]
04DA	04DF	 # [6]
04E2	04E7	 # [6]
04EA	04F5	 # [12]
04F8	04F9	 # [2]
0622	0626	 # [5]
06C0		
06C2		
06D3		
0929		
0931		
0934		
0958	095F	 # [8]
09CB	09CC	 # [2]
09DC	09DD	 # [2]
09DF		
0A33		
0A36		
0A59	0A5B	 # [3]
0A5E		
0B48		
0B4B	0B4C	 # [2]
0B5C	0B5D	 # [2]
0B94		
0BCA	0BCC	 # [3]
0C48		
0CC0		
0CC7	0CC8	 # [2]
0CCA	0CCB	 # [2]
0D4A	0D4C	 # [3]
0DDA		
0DDC	0DDE	 # [3]
0F43		
0F4D		
0F52		
0F57		
0F5C		
0F69		
0F73		
0F75	0F76	 # [2]
0F78		
0F81		
0F93		
0F9D		
0FA2		
0FA7		
0FAC		
0FB9		
1026		
1B06		
1B08		
1B0A		
1B0C		
1B0E		
1B12		
1B3B		
1B3D		
1B40	1B41	 # [2]
1B43		
1E00	1E99	 # [154]
1E9B		
1EA0	1EF9	 # [90]
1F00	1F15	 # [22]
1F18	1F1D	 # [6]
1F20	1F45	 # [38]
1F48	1F4D	 # [6]
1F50	1F57	 # [8]
1F59		
1F5B		
1F5D		
1F5F	1F7D	 # [31]
1F80	1FB4	 # [53]
1FB6	1FBC	 # [7]
1FBE		
1FC1	1FC4	 # [4]
1FC6	1FD3	 # [14]
1FD6	1FDB	 # [6]
1FDD	1FEF	 # [19]
1FF2	1FF4	 # [3]
1FF6	1FFD	 # [8]
2000	2001	 # [2]
2126		
212A	212B	 # [2]
219A	219B	 # [2]
21AE		
21CD	21CF	 # [3]
2204		
2209		
220C		
2224		
2226		
2241		
2244		
2247		
2249		
2260		
2262		
226D	2271	 # [5]
2274	2275	 # [2]
2278	2279	 # [2]
2280	2281	 # [2]
2284	2285	 # [2]
2288	2289	 # [2]
22AC	22AF	 # [4]
22E0	22E3	 # [4]
22EA	22ED	 # [4]
2329	232A	 # [2]
2ADC		
304C		
304E		
3050		
3052		
3054		
3056		
3058		
305A		
305C		
305E		
3060		
3062		
3065		
3067		
3069		
3070	3071	 # [2]
3073	3074	 # [2]
3076	3077	 # [2]
3079	307A	 # [2]
307C	307D	 # [2]
3094		
309E		
30AC		
30AE		
30B0		
30B2		
30B4		
30B6		
30B8		
30BA		
30BC		
30BE		
30C0		
30C2		
30C5		
30C7		
30C9		
30D0	30D1	 # [2]
30D3	30D4	 # [2]
30D6	30D7	 # [2]
30D9	30DA	 # [2]
30DC	30DD	 # [2]
30F4		
30F7	30FA	 # [4]
30FE		
AC00	D7A3	 # [11_172]
F900	FA0D	 # [270]
FA10		
FA12		
FA15	FA1E	 # [10]
FA20		
FA22		
FA25	FA26	 # [2]
FA2A	FA2D	 # [4]
FA30	FA6D	 # [62]
FA70	FAD9	 # [106]
FB1D		
FB1F		
FB2A	FB36	 # [13]
FB38	FB3C	 # [5]
FB3E		
FB40	FB41	 # [2]
FB43	FB44	 # [2]
FB46	FB4E	 # [9]
1109A		
1109C		
110AB		
1D15E	1D164	 # [7]
1D1BB	1D1C0	 # [6]
2F800	2FA1D	 # [542]
END
