# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# 'X' below means that this form is discouraged.  Consult perluniprops.pod
# 
# This file returns the 1024 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Block=Mathematical_Alphanumeric_Symbols}
#         \p{Blk=Mathematical_Alphanumeric_Symbols}
#         \p{Is_Block=Mathematical_Alphanumeric_Symbols}
#         \p{Is_Blk=Mathematical_Alphanumeric_Symbols}
# 
# X       \p{Mathematical_Alphanumeric_Symbols}
# X       \p{Is_Mathematical_Alphanumeric_Symbols}
#         \p{In_Mathematical_Alphanumeric_Symbols}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Blk: Mathematical_Alphanumeric_Symbols}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
1D400	1D7FF	 # [1024]
END
