# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 72 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Script=Tamil}
#         \p{Sc=Taml}
#         \p{Is_Script=Tamil}
#         \p{Is_Sc=Taml}
# 
#         \p{Tamil}
#         \p{Is_Tamil}
#         \p{Taml}
#         \p{Is_Taml}
# 
#     Note that contrary to what you might expect, the above is NOT the same
#     as \p{Block=Tamil}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Sc: Tamil}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0B82	0B83	 # [2]
0B85	0B8A	 # [6]
0B8E	0B90	 # [3]
0B92	0B95	 # [4]
0B99	0B9A	 # [2]
0B9C		
0B9E	0B9F	 # [2]
0BA3	0BA4	 # [2]
0BA8	0BAA	 # [3]
0BAE	0BB9	 # [12]
0BBE	0BC2	 # [5]
0BC6	0BC8	 # [3]
0BCA	0BCD	 # [4]
0BD0		
0BD7		
0BE6	0BFA	 # [21]
END
