# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file is for tables that are not necessarily related:  To conserve
# resources, every table that matches the identical set of code points in
# this version of Unicode uses this file.  Each one is listed in a separate
# group below.  It could be that the tables will match the same set of code
# points in other Unicode releases, or it could be purely coincidence that
# they happen to be the same in Unicode 5.2.0, and hence may not in other
# versions.
# 
# This file returns the 1455 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Sentence_Break=Extend}
#         \p{SB=EX}
#         \p{Is_Sentence_Break=Extend}
#         \p{Is_SB=EX}
# 
#         \p{Word_Break=Extend}
#         \p{WB=Extend}
#         \p{Is_Word_Break=Extend}
#         \p{Is_WB=Extend}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and within each group
# above, anything to the left of the equals (or colon) can be combined with
# anything to the right.  Thus, for example,
#         \p{Is_WB: Extend}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0300	036F	 # [112]
0483	0489	 # [7]
0591	05BD	 # [45]
05BF		
05C1	05C2	 # [2]
05C4	05C5	 # [2]
05C7		
0610	061A	 # [11]
064B	065E	 # [20]
0670		
06D6	06DC	 # [7]
06DE	06E4	 # [7]
06E7	06E8	 # [2]
06EA	06ED	 # [4]
0711		
0730	074A	 # [27]
07A6	07B0	 # [11]
07EB	07F3	 # [9]
0816	0819	 # [4]
081B	0823	 # [9]
0825	0827	 # [3]
0829	082D	 # [5]
0900	0903	 # [4]
093C		
093E	094E	 # [17]
0951	0955	 # [5]
0962	0963	 # [2]
0981	0983	 # [3]
09BC		
09BE	09C4	 # [7]
09C7	09C8	 # [2]
09CB	09CD	 # [3]
09D7		
09E2	09E3	 # [2]
0A01	0A03	 # [3]
0A3C		
0A3E	0A42	 # [5]
0A47	0A48	 # [2]
0A4B	0A4D	 # [3]
0A51		
0A70	0A71	 # [2]
0A75		
0A81	0A83	 # [3]
0ABC		
0ABE	0AC5	 # [8]
0AC7	0AC9	 # [3]
0ACB	0ACD	 # [3]
0AE2	0AE3	 # [2]
0B01	0B03	 # [3]
0B3C		
0B3E	0B44	 # [7]
0B47	0B48	 # [2]
0B4B	0B4D	 # [3]
0B56	0B57	 # [2]
0B62	0B63	 # [2]
0B82		
0BBE	0BC2	 # [5]
0BC6	0BC8	 # [3]
0BCA	0BCD	 # [4]
0BD7		
0C01	0C03	 # [3]
0C3E	0C44	 # [7]
0C46	0C48	 # [3]
0C4A	0C4D	 # [4]
0C55	0C56	 # [2]
0C62	0C63	 # [2]
0C82	0C83	 # [2]
0CBC		
0CBE	0CC4	 # [7]
0CC6	0CC8	 # [3]
0CCA	0CCD	 # [4]
0CD5	0CD6	 # [2]
0CE2	0CE3	 # [2]
0D02	0D03	 # [2]
0D3E	0D44	 # [7]
0D46	0D48	 # [3]
0D4A	0D4D	 # [4]
0D57		
0D62	0D63	 # [2]
0D82	0D83	 # [2]
0DCA		
0DCF	0DD4	 # [6]
0DD6		
0DD8	0DDF	 # [8]
0DF2	0DF3	 # [2]
0E31		
0E34	0E3A	 # [7]
0E47	0E4E	 # [8]
0EB1		
0EB4	0EB9	 # [6]
0EBB	0EBC	 # [2]
0EC8	0ECD	 # [6]
0F18	0F19	 # [2]
0F35		
0F37		
0F39		
0F3E	0F3F	 # [2]
0F71	0F84	 # [20]
0F86	0F87	 # [2]
0F90	0F97	 # [8]
0F99	0FBC	 # [36]
0FC6		
102B	103E	 # [20]
1056	1059	 # [4]
105E	1060	 # [3]
1062	1064	 # [3]
1067	106D	 # [7]
1071	1074	 # [4]
1082	108D	 # [12]
108F		
109A	109D	 # [4]
135F		
1712	1714	 # [3]
1732	1734	 # [3]
1752	1753	 # [2]
1772	1773	 # [2]
17B6	17D3	 # [30]
17DD		
180B	180D	 # [3]
18A9		
1920	192B	 # [12]
1930	193B	 # [12]
19B0	19C0	 # [17]
19C8	19C9	 # [2]
1A17	1A1B	 # [5]
1A55	1A5E	 # [10]
1A60	1A7C	 # [29]
1A7F		
1B00	1B04	 # [5]
1B34	1B44	 # [17]
1B6B	1B73	 # [9]
1B80	1B82	 # [3]
1BA1	1BAA	 # [10]
1C24	1C37	 # [20]
1CD0	1CD2	 # [3]
1CD4	1CE8	 # [21]
1CED		
1CF2		
1DC0	1DE6	 # [39]
1DFD	1DFF	 # [3]
200C	200D	 # [2]
20D0	20F0	 # [33]
2CEF	2CF1	 # [3]
2DE0	2DFF	 # [32]
302A	302F	 # [6]
3099	309A	 # [2]
A66F	A672	 # [4]
A67C	A67D	 # [2]
A6F0	A6F1	 # [2]
A802		
A806		
A80B		
A823	A827	 # [5]
A880	A881	 # [2]
A8B4	A8C4	 # [17]
A8E0	A8F1	 # [18]
A926	A92D	 # [8]
A947	A953	 # [13]
A980	A983	 # [4]
A9B3	A9C0	 # [14]
AA29	AA36	 # [14]
AA43		
AA4C	AA4D	 # [2]
AA7B		
AAB0		
AAB2	AAB4	 # [3]
AAB7	AAB8	 # [2]
AABE	AABF	 # [2]
AAC1		
ABE3	ABEA	 # [8]
ABEC	ABED	 # [2]
FB1E		
FE00	FE0F	 # [16]
FE20	FE26	 # [7]
FF9E	FF9F	 # [2]
101FD		
10A01	10A03	 # [3]
10A05	10A06	 # [2]
10A0C	10A0F	 # [4]
10A38	10A3A	 # [3]
10A3F		
11080	11082	 # [3]
110B0	110BA	 # [11]
1D165	1D169	 # [5]
1D16D	1D172	 # [6]
1D17B	1D182	 # [8]
1D185	1D18B	 # [7]
1D1AA	1D1AD	 # [4]
1D242	1D244	 # [3]
E0100	E01EF	 # [240]
END
