# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file is for tables that are not necessarily related:  To conserve
# resources, every table that matches the identical set of code points in
# this version of Unicode uses this file.  Each one is listed in a separate
# group below.  It could be that the tables will match the same set of code
# points in other Unicode releases, or it could be purely coincidence that
# they happen to be the same in Unicode 5.2.0, and hence may not in other
# versions.
# 
# This file returns the 0 code points in Unicode Version 5.2.0 that match any
# of the following regular expression constructs:
# 
#         \p{Canonical_Combining_Class=Attached_Below_Left}
#         \p{Ccc=ATBL}
#         \p{Is_Canonical_Combining_Class=200}
#         \p{Is_Ccc=Attached_Below_Left}
# 
#         \p{Joining_Type=Left_Joining}
#         \p{Jt=L}
#         \p{Is_Joining_Type=Left_Joining}
#         \p{Is_Jt=L}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and within each group
# above, anything to the left of the equals (or colon) can be combined with
# anything to the right.  Thus, for example,
#         \p{Is_Jt: Left_Joining}
# is also valid.

return <<'END';
!utf8::IsAny
END
