# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 177 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Sentence_Break=Close}
#         \p{SB=CL}
#         \p{Is_Sentence_Break=Close}
#         \p{Is_SB=CL}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_SB: Close}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0022		
0027	0029	 # [3]
005B		
005D		
007B		
007D		
00AB		
00BB		
0F3A	0F3D	 # [4]
169B	169C	 # [2]
2018	201F	 # [8]
2039	203A	 # [2]
2045	2046	 # [2]
207D	207E	 # [2]
208D	208E	 # [2]
2329	232A	 # [2]
275B	275E	 # [4]
2768	2775	 # [14]
27C5	27C6	 # [2]
27E6	27EF	 # [10]
2983	2998	 # [22]
29D8	29DB	 # [4]
29FC	29FD	 # [2]
2E00	2E0D	 # [14]
2E1C	2E1D	 # [2]
2E20	2E29	 # [10]
3008	3011	 # [10]
3014	301B	 # [8]
301D	301F	 # [3]
FD3E	FD3F	 # [2]
FE17	FE18	 # [2]
FE35	FE44	 # [16]
FE47	FE48	 # [2]
FE59	FE5E	 # [6]
FF08	FF09	 # [2]
FF3B		
FF3D		
FF5B		
FF5D		
FF5F	FF60	 # [2]
FF62	FF63	 # [2]
END
