# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 82 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Decomposition_Type=Medial}
#         \p{Dt=Med}
#         \p{Is_Decomposition_Type=Medial}
#         \p{Is_Dt=Med}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Dt: Medial}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
FB55		
FB59		
FB5D		
FB61		
FB65		
FB69		
FB6D		
FB71		
FB75		
FB79		
FB7D		
FB81		
FB91		
FB95		
FB99		
FB9D		
FBA3		
FBA9		
FBAD		
FBD6		
FBE7		
FBE9		
FBFF		
FCDF	FCF4	 # [22]
FD34	FD3B	 # [8]
FE71		
FE77		
FE79		
FE7B		
FE7D		
FE7F		
FE8C		
FE92		
FE98		
FE9C		
FEA0		
FEA4		
FEA8		
FEB4		
FEB8		
FEBC		
FEC0		
FEC4		
FEC8		
FECC		
FED0		
FED4		
FED8		
FEDC		
FEE0		
FEE4		
FEE8		
FEEC		
FEF4		
END
