# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 1_111_951 code points in Unicode Version 5.2.0 that
# match any of the following regular expression constructs:
# 
#         \p{Math=No}
#         \p{Is_Math=N}
#         \p{Math=F}
#         \p{Is_Math=False}
# 
#         \P{Math}
#         \P{Is_Math}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Math: No}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0000	002A	 # [43]
002C	003B	 # [16]
003F	005D	 # [31]
005F	007B	 # [29]
007D		
007F	00AB	 # [45]
00AD	00B0	 # [4]
00B2	00D6	 # [37]
00D8	00F6	 # [31]
00F8	03CF	 # [728]
03D3	03D4	 # [2]
03D6	03EF	 # [26]
03F2	03F3	 # [2]
03F7	0605	 # [527]
0609	2015	 # [6669]
2017	2031	 # [27]
2035	203F	 # [11]
2041	2043	 # [3]
2045	2051	 # [13]
2053	2060	 # [14]
2065	2079	 # [21]
207F	2089	 # [11]
208F	20CF	 # [65]
20DD	20E0	 # [4]
20E2	20E4	 # [3]
20E7	20EA	 # [4]
20F0	2101	 # [18]
2103	2109	 # [7]
2114		
2116	2118	 # [3]
211E	2123	 # [6]
2125	2127	 # [3]
212A	212B	 # [2]
212E		
2132		
2139	213B	 # [3]
214A		
214C	218F	 # [68]
21A8		
21AF		
21B2	21B5	 # [4]
21B8	21BB	 # [4]
21DC		
21DE	21E3	 # [6]
21E6	21F3	 # [14]
2300	2307	 # [8]
230C	231F	 # [20]
2322	237B	 # [90]
237D	239A	 # [30]
23B6		
23B8	23CF	 # [24]
23D1	23DB	 # [11]
23E3	259F	 # [445]
25A2	25AD	 # [12]
25B8	25BB	 # [4]
25C2	25C5	 # [4]
25C8	25C9	 # [2]
25CC	25CE	 # [3]
25D4	25E1	 # [14]
25E3		
25E5	25E6	 # [2]
25ED	25F7	 # [11]
2600	2604	 # [5]
2607	263F	 # [57]
2641		
2643	265F	 # [29]
2664	266C	 # [9]
2670	27BF	 # [336]
27CB		
27CD	27CF	 # [3]
2800	28FF	 # [256]
2B00	2B2F	 # [48]
2B45	2B46	 # [2]
2B4D	FB28	 # [53_212]
FB2A	FE60	 # [823]
FE67		
FE69	FF0A	 # [162]
FF0C	FF1B	 # [16]
FF1F	FF3B	 # [29]
FF3D		
FF3F	FF5B	 # [29]
FF5D		
FF5F	FFE1	 # [131]
FFE3	FFE8	 # [6]
FFED	1D3FF	 # [54_291]
1D455		
1D49D		
1D4A0	1D4A1	 # [2]
1D4A3	1D4A4	 # [2]
1D4A7	1D4A8	 # [2]
1D4AD		
1D4BA		
1D4BC		
1D4C4		
1D506		
1D50B	1D50C	 # [2]
1D515		
1D51D		
1D53A		
1D53F		
1D545		
1D547	1D549	 # [3]
1D551		
1D6A6	1D6A7	 # [2]
1D7CC	1D7CD	 # [2]
1D800	10FFFF	 # [993_280]
END
