# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 44_978 code points in Unicode Version 5.2.0 that
# match any of the following regular expression constructs:
# 
#         \p{Age=3.1}
#         \p{Is_Age=3.1}
# 
#     Meaning: Code point's usage was introduced in version 3.1
# 
#     Note: See also Property 'Present_In'
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Age: 3.1}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
03F4	03F5	 # [2]
FDD0	FDEF	 # [32]
10300	1031E	 # [31]
10320	10323	 # [4]
10330	1034A	 # [27]
10400	10425	 # [38]
10428	1044D	 # [38]
1D000	1D0F5	 # [246]
1D100	1D126	 # [39]
1D12A	1D1DD	 # [180]
1D400	1D454	 # [85]
1D456	1D49C	 # [71]
1D49E	1D49F	 # [2]
1D4A2		
1D4A5	1D4A6	 # [2]
1D4A9	1D4AC	 # [4]
1D4AE	1D4B9	 # [12]
1D4BB		
1D4BD	1D4C0	 # [4]
1D4C2	1D4C3	 # [2]
1D4C5	1D505	 # [65]
1D507	1D50A	 # [4]
1D50D	1D514	 # [8]
1D516	1D51C	 # [7]
1D51E	1D539	 # [28]
1D53B	1D53E	 # [4]
1D540	1D544	 # [5]
1D546		
1D54A	1D550	 # [7]
1D552	1D6A3	 # [338]
1D6A8	1D7C9	 # [290]
1D7CE	1D7FF	 # [50]
20000	2A6D6	 # [42_711]
2F800	2FA1D	 # [542]
E0001		
E0020	E007F	 # [96]
END
