# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 318 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Canonical_Combining_Class=Above}
#         \p{Ccc=A}
#         \p{Is_Canonical_Combining_Class=230}
#         \p{Is_Ccc=Above}
# 
#         \p{_CombAbove}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Ccc: Above}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0300	0314	 # [21]
033D	0344	 # [8]
0346		
034A	034C	 # [3]
0350	0352	 # [3]
0357		
035B		
0363	036F	 # [13]
0483	0487	 # [5]
0592	0595	 # [4]
0597	0599	 # [3]
059C	05A1	 # [6]
05A8	05A9	 # [2]
05AB	05AC	 # [2]
05AF		
05C4		
0610	0617	 # [8]
0653	0654	 # [2]
0657	065B	 # [5]
065D	065E	 # [2]
06D6	06DC	 # [7]
06DF	06E2	 # [4]
06E4		
06E7	06E8	 # [2]
06EB	06EC	 # [2]
0730		
0732	0733	 # [2]
0735	0736	 # [2]
073A		
073D		
073F	0741	 # [3]
0743		
0745		
0747		
0749	074A	 # [2]
07EB	07F1	 # [7]
07F3		
0816	0819	 # [4]
081B	0823	 # [9]
0825	0827	 # [3]
0829	082D	 # [5]
0951		
0953	0954	 # [2]
0F82	0F83	 # [2]
0F86	0F87	 # [2]
135F		
17DD		
193A		
1A17		
1A75	1A7C	 # [8]
1B6B		
1B6D	1B73	 # [7]
1CD0	1CD2	 # [3]
1CDA	1CDB	 # [2]
1CE0		
1DC0	1DC1	 # [2]
1DC3	1DC9	 # [7]
1DCB	1DCC	 # [2]
1DD1	1DE6	 # [22]
1DFE		
20D0	20D1	 # [2]
20D4	20D7	 # [4]
20DB	20DC	 # [2]
20E1		
20E7		
20E9		
20F0		
2CEF	2CF1	 # [3]
2DE0	2DFF	 # [32]
A66F		
A67C	A67D	 # [2]
A6F0	A6F1	 # [2]
A8E0	A8F1	 # [18]
AAB0		
AAB2	AAB3	 # [2]
AAB7	AAB8	 # [2]
AABE	AABF	 # [2]
AAC1		
FE20	FE26	 # [7]
10A0F		
10A38		
1D185	1D189	 # [5]
1D1AA	1D1AD	 # [4]
1D242	1D244	 # [3]
END
