# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 720 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Decomposition_Type=Compat}
#         \p{Dt=Com}
#         \p{Is_Decomposition_Type=Compat}
#         \p{Is_Dt=Com}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Dt: Compat}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
00A8		
00AF		
00B4	00B5	 # [2]
00B8		
0132	0133	 # [2]
013F	0140	 # [2]
0149		
017F		
01C4	01CC	 # [9]
01F1	01F3	 # [3]
02D8	02DD	 # [6]
037A		
0384		
03D0	03D2	 # [3]
03D5	03D6	 # [2]
03F0	03F2	 # [3]
03F4	03F5	 # [2]
03F9		
0587		
0675	0678	 # [4]
0E33		
0EB3		
0EDC	0EDD	 # [2]
0F77		
0F79		
1E9A		
1FBD		
1FBF	1FC0	 # [2]
1FFE		
2002	2006	 # [5]
2008	200A	 # [3]
2017		
2024	2026	 # [3]
2033	2034	 # [2]
2036	2037	 # [2]
203C		
203E		
2047	2049	 # [3]
2057		
205F		
20A8		
2100	2101	 # [2]
2103		
2105	2107	 # [3]
2109		
2116		
2121		
2135	2138	 # [4]
213B		
2160	217F	 # [32]
222C	222D	 # [2]
222F	2230	 # [2]
2474	24B5	 # [66]
2A0C		
2A74	2A76	 # [3]
2E9F		
2EF3		
2F00	2FD5	 # [214]
3036		
3038	303A	 # [3]
309B	309C	 # [2]
3131	318E	 # [94]
3200	321E	 # [31]
3220	3243	 # [36]
32C0	32CB	 # [12]
3358	3370	 # [25]
33E0	33FE	 # [31]
FB00	FB06	 # [7]
FB13	FB17	 # [5]
FB4F		
FE49	FE4F	 # [7]
1F100	1F10A	 # [11]
1F110	1F12A	 # [27]
1F240	1F248	 # [9]
END
