# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file is for tables that are not necessarily related:  To conserve
# resources, every table that matches the identical set of code points in
# this version of Unicode uses this file.  Each one is listed in a separate
# group below.  It could be that the tables will match the same set of code
# points in other Unicode releases, or it could be purely coincidence that
# they happen to be the same in Unicode 5.2.0, and hence may not in other
# versions.
# 
# This file returns the 411 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Numeric_Type=Decimal}
#         \p{Nt=De}
#         \p{Is_Numeric_Type=Decimal}
#         \p{Is_Nt=De}
# 
#         \p{General_Category=Decimal_Number}
#         \p{Gc=Nd}
#         \p{Category=Digit}
#         \p{Is_General_Category=Decimal_Number}
#         \p{Is_Gc=Nd}
#         \p{Is_Category=Digit}
# 
#         \p{Digit}
#         \p{Is_Digit}
#         \p{Decimal_Number}
#         \p{Is_Decimal_Number}
#         \p{Nd}
#         \p{Is_Nd}
# 
#     Meaning: \d, extended beyond just [0-9]
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and within each group
# above, anything to the left of the equals (or colon) can be combined with
# anything to the right.  Thus, for example,
#         \p{Is_Category: Decimal_Number}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0030	0039	 # [10]
0660	0669	 # [10]
06F0	06F9	 # [10]
07C0	07C9	 # [10]
0966	096F	 # [10]
09E6	09EF	 # [10]
0A66	0A6F	 # [10]
0AE6	0AEF	 # [10]
0B66	0B6F	 # [10]
0BE6	0BEF	 # [10]
0C66	0C6F	 # [10]
0CE6	0CEF	 # [10]
0D66	0D6F	 # [10]
0E50	0E59	 # [10]
0ED0	0ED9	 # [10]
0F20	0F29	 # [10]
1040	1049	 # [10]
1090	1099	 # [10]
17E0	17E9	 # [10]
1810	1819	 # [10]
1946	194F	 # [10]
19D0	19DA	 # [11]
1A80	1A89	 # [10]
1A90	1A99	 # [10]
1B50	1B59	 # [10]
1BB0	1BB9	 # [10]
1C40	1C49	 # [10]
1C50	1C59	 # [10]
A620	A629	 # [10]
A8D0	A8D9	 # [10]
A900	A909	 # [10]
A9D0	A9D9	 # [10]
AA50	AA59	 # [10]
ABF0	ABF9	 # [10]
FF10	FF19	 # [10]
104A0	104A9	 # [10]
1D7CE	1D7FF	 # [50]
END
