# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 1_113_951 code points in Unicode Version 5.2.0 that
# match any of the following regular expression constructs:
# 
#         \p{Terminal_Punctuation=No}
#         \p{Term=N}
#         \p{Is_Terminal_Punctuation=F}
#         \p{Is_Term=False}
# 
#         \P{Terminal_Punctuation}
#         \P{Is_Terminal_Punctuation}
#         \P{Term}
#         \P{Is_Term}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Term: No}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0000	0020	 # [33]
0022	002B	 # [10]
002D		
002F	0039	 # [11]
003C	003E	 # [3]
0040	037D	 # [830]
037F	0386	 # [8]
0388	0588	 # [513]
058A	05C2	 # [57]
05C4	060B	 # [72]
060D	061A	 # [14]
061C	061E	 # [3]
0620	06D3	 # [180]
06D5	06FF	 # [43]
070B		
070D	07F7	 # [235]
07FA	082F	 # [54]
083F	0963	 # [293]
0966	0E59	 # [1268]
0E5C	0F07	 # [172]
0F09	0F0C	 # [4]
0F13	1049	 # [311]
104C	1360	 # [789]
1369	166C	 # [772]
166F	16EA	 # [124]
16EE	17D3	 # [230]
17D7	17D9	 # [3]
17DB	1801	 # [39]
1806	1807	 # [2]
180A	1943	 # [314]
1946	1AA7	 # [354]
1AAC	1B59	 # [174]
1B5C		
1B60	1C3A	 # [219]
1C40	1C7D	 # [62]
1C80	203B	 # [956]
203E	2046	 # [9]
204A	2E2D	 # [3556]
2E2F	3000	 # [466]
3003	A4FD	 # [29_947]
A500	A60C	 # [269]
A610	A6F2	 # [227]
A6F8	A875	 # [382]
A878	A8CD	 # [86]
A8D0	A92E	 # [95]
A930	A9C6	 # [151]
A9CA	AA5C	 # [147]
AA60	AADE	 # [127]
AAE0	ABEA	 # [267]
ABEC	FE4F	 # [21_092]
FE53		
FE58	FF00	 # [169]
FF02	FF0B	 # [10]
FF0D		
FF0F	FF19	 # [11]
FF1C	FF1E	 # [3]
FF20	FF60	 # [65]
FF62	FF63	 # [2]
FF65	1039E	 # [1082]
103A0	103CF	 # [48]
103D1	10856	 # [1158]
10858	1091E	 # [199]
10920	10B39	 # [538]
10B40	110BD	 # [1406]
110C2	1246F	 # [5038]
12474	10FFFF	 # [1_039_244]
END
