# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 389 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{General_Category=Other_Punctuation}
#         \p{Gc=Po}
#         \p{Category=Other_Punctuation}
#         \p{Is_General_Category=Po}
#         \p{Is_Gc=Other_Punctuation}
#         \p{Is_Category=Po}
# 
#         \p{Other_Punctuation}
#         \p{Is_Other_Punctuation}
#         \p{Po}
#         \p{Is_Po}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Category: Other_Punctuation}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0021	0023	 # [3]
0025	0027	 # [3]
002A		
002C		
002E	002F	 # [2]
003A	003B	 # [2]
003F	0040	 # [2]
005C		
00A1		
00B7		
00BF		
037E		
0387		
055A	055F	 # [6]
0589		
05C0		
05C3		
05C6		
05F3	05F4	 # [2]
0609	060A	 # [2]
060C	060D	 # [2]
061B		
061E	061F	 # [2]
066A	066D	 # [4]
06D4		
0700	070D	 # [14]
07F7	07F9	 # [3]
0830	083E	 # [15]
0964	0965	 # [2]
0970		
0DF4		
0E4F		
0E5A	0E5B	 # [2]
0F04	0F12	 # [15]
0F85		
0FD0	0FD4	 # [5]
104A	104F	 # [6]
10FB		
1361	1368	 # [8]
166D	166E	 # [2]
16EB	16ED	 # [3]
1735	1736	 # [2]
17D4	17D6	 # [3]
17D8	17DA	 # [3]
1800	1805	 # [6]
1807	180A	 # [4]
1944	1945	 # [2]
19DE	19DF	 # [2]
1A1E	1A1F	 # [2]
1AA0	1AA6	 # [7]
1AA8	1AAD	 # [6]
1B5A	1B60	 # [7]
1C3B	1C3F	 # [5]
1C7E	1C7F	 # [2]
1CD3		
2016	2017	 # [2]
2020	2027	 # [8]
2030	2038	 # [9]
203B	203E	 # [4]
2041	2043	 # [3]
2047	2051	 # [11]
2053		
2055	205E	 # [10]
2CF9	2CFC	 # [4]
2CFE	2CFF	 # [2]
2E00	2E01	 # [2]
2E06	2E08	 # [3]
2E0B		
2E0E	2E16	 # [9]
2E18	2E19	 # [2]
2E1B		
2E1E	2E1F	 # [2]
2E2A	2E2E	 # [5]
2E30	2E31	 # [2]
3001	3003	 # [3]
303D		
30FB		
A4FE	A4FF	 # [2]
A60D	A60F	 # [3]
A673		
A67E		
A6F2	A6F7	 # [6]
A874	A877	 # [4]
A8CE	A8CF	 # [2]
A8F8	A8FA	 # [3]
A92E	A92F	 # [2]
A95F		
A9C1	A9CD	 # [13]
A9DE	A9DF	 # [2]
AA5C	AA5F	 # [4]
AADE	AADF	 # [2]
ABEB		
FE10	FE16	 # [7]
FE19		
FE30		
FE45	FE46	 # [2]
FE49	FE4C	 # [4]
FE50	FE52	 # [3]
FE54	FE57	 # [4]
FE5F	FE61	 # [3]
FE68		
FE6A	FE6B	 # [2]
FF01	FF03	 # [3]
FF05	FF07	 # [3]
FF0A		
FF0C		
FF0E	FF0F	 # [2]
FF1A	FF1B	 # [2]
FF1F	FF20	 # [2]
FF3C		
FF61		
FF64	FF65	 # [2]
10100	10101	 # [2]
1039F		
103D0		
10857		
1091F		
1093F		
10A50	10A58	 # [9]
10A7F		
10B39	10B3F	 # [7]
110BB	110BC	 # [2]
110BE	110C1	 # [4]
12470	12473	 # [4]
END
