# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# 'D' below means that this form is deprecated.  Consult perluniprops.pod
# 
# This file returns the 1216 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
# D       \p{Other_Math=Yes}
# D       \p{OMath=Y}
# D       \p{Is_Other_Math=T}
# D       \p{Is_OMath=True}
# 
# D       \p{Other_Math}
# D       \p{Is_Other_Math}
# D       \p{OMath}
# D       \p{Is_OMath}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_OMath: Yes}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
005E		
03D0	03D2	 # [3]
03D5		
03F0	03F1	 # [2]
03F4	03F5	 # [2]
2016		
2032	2034	 # [3]
2040		
2061	2064	 # [4]
207D	207E	 # [2]
208D	208E	 # [2]
20D0	20DC	 # [13]
20E1		
20E5	20E6	 # [2]
20EB	20EF	 # [5]
2102		
210A	2113	 # [10]
2115		
2119	211D	 # [5]
2124		
2128	2129	 # [2]
212C	212D	 # [2]
212F	2131	 # [3]
2133	2138	 # [6]
213C	213F	 # [4]
2145	2149	 # [5]
2195	2199	 # [5]
219C	219F	 # [4]
21A1	21A2	 # [2]
21A4	21A5	 # [2]
21A7		
21A9	21AD	 # [5]
21B0	21B1	 # [2]
21B6	21B7	 # [2]
21BC	21CD	 # [18]
21D0	21D1	 # [2]
21D3		
21D5	21DB	 # [7]
21DD		
21E4	21E5	 # [2]
23B4	23B5	 # [2]
23B7		
23D0		
23E2		
25A0	25A1	 # [2]
25AE	25B6	 # [9]
25BC	25C0	 # [5]
25C6	25C7	 # [2]
25CA	25CB	 # [2]
25CF	25D3	 # [5]
25E2		
25E4		
25E7	25EC	 # [6]
2605	2606	 # [2]
2640		
2642		
2660	2663	 # [4]
266D	266E	 # [2]
27C5	27C6	 # [2]
27E6	27EF	 # [10]
2983	2998	 # [22]
29D8	29DB	 # [4]
29FC	29FD	 # [2]
FE61		
FE63		
FE68		
FF3C		
FF3E		
1D400	1D454	 # [85]
1D456	1D49C	 # [71]
1D49E	1D49F	 # [2]
1D4A2		
1D4A5	1D4A6	 # [2]
1D4A9	1D4AC	 # [4]
1D4AE	1D4B9	 # [12]
1D4BB		
1D4BD	1D4C3	 # [7]
1D4C5	1D505	 # [65]
1D507	1D50A	 # [4]
1D50D	1D514	 # [8]
1D516	1D51C	 # [7]
1D51E	1D539	 # [28]
1D53B	1D53E	 # [4]
1D540	1D544	 # [5]
1D546		
1D54A	1D550	 # [7]
1D552	1D6A5	 # [340]
1D6A8	1D6C0	 # [25]
1D6C2	1D6DA	 # [25]
1D6DC	1D6FA	 # [31]
1D6FC	1D714	 # [25]
1D716	1D734	 # [31]
1D736	1D74E	 # [25]
1D750	1D76E	 # [31]
1D770	1D788	 # [25]
1D78A	1D7A8	 # [31]
1D7AA	1D7C2	 # [25]
1D7C4	1D7CB	 # [8]
1D7CE	1D7FF	 # [50]
END
