# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 461 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Script=Ethiopic}
#         \p{Sc=Ethi}
#         \p{Is_Script=Ethiopic}
#         \p{Is_Sc=Ethi}
# 
#         \p{Ethiopic}
#         \p{Is_Ethiopic}
#         \p{Ethi}
#         \p{Is_Ethi}
# 
#     Note that contrary to what you might expect, the above is NOT the same
#     as \p{Block=Ethiopic}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Sc: Ethiopic}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
1200	1248	 # [73]
124A	124D	 # [4]
1250	1256	 # [7]
1258		
125A	125D	 # [4]
1260	1288	 # [41]
128A	128D	 # [4]
1290	12B0	 # [33]
12B2	12B5	 # [4]
12B8	12BE	 # [7]
12C0		
12C2	12C5	 # [4]
12C8	12D6	 # [15]
12D8	1310	 # [57]
1312	1315	 # [4]
1318	135A	 # [67]
135F	137C	 # [30]
1380	1399	 # [26]
2D80	2D96	 # [23]
2DA0	2DA6	 # [7]
2DA8	2DAE	 # [7]
2DB0	2DB6	 # [7]
2DB8	2DBE	 # [7]
2DC0	2DC6	 # [7]
2DC8	2DCE	 # [7]
2DD0	2DD6	 # [7]
2DD8	2DDE	 # [7]
END
