# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 1_113_569 code points in Unicode Version 5.2.0 that
# match any of the following regular expression constructs:
# 
#         \p{Bidi_Mirrored=No}
#         \p{Bidi_M=N}
#         \p{Is_Bidi_Mirrored=F}
#         \p{Is_Bidi_M=False}
# 
#         \P{Bidi_Mirrored}
#         \P{Is_Bidi_Mirrored}
#         \P{Bidi_M}
#         \P{Is_Bidi_M}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Bidi_M: No}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0000	0027	 # [40]
002A	003B	 # [18]
003D		
003F	005A	 # [28]
005C		
005E	007A	 # [29]
007C		
007E	00AA	 # [45]
00AC	00BA	 # [15]
00BC	0F39	 # [3710]
0F3E	169A	 # [1885]
169D	2038	 # [2460]
203B	2044	 # [10]
2047	207C	 # [54]
207F	208C	 # [14]
208F	213F	 # [177]
2141	2200	 # [192]
2205	2207	 # [3]
220E	2210	 # [3]
2212	2214	 # [3]
2217	2219	 # [3]
221E		
2223		
2225		
2227	222A	 # [4]
2234	2238	 # [5]
223A		
224D	2251	 # [5]
2256	225E	 # [9]
2261		
2263		
226C	226D	 # [2]
228D	228E	 # [2]
2293	2297	 # [5]
2299	22A1	 # [9]
22A4	22A5	 # [2]
22B9	22BD	 # [5]
22C0	22C8	 # [9]
22CE	22CF	 # [2]
22D2	22D5	 # [4]
22EE	22EF	 # [2]
2300	2307	 # [8]
230C	231F	 # [20]
2322	2328	 # [7]
232B	2767	 # [1085]
2776	27BF	 # [74]
27C1	27C2	 # [2]
27C7		
27CA	27CB	 # [2]
27CD	27D2	 # [6]
27D7	27DB	 # [5]
27DF	27E1	 # [3]
27F0	2982	 # [403]
2999	299A	 # [2]
29B0	29B7	 # [8]
29B9	29BF	 # [7]
29C6	29C8	 # [3]
29CA	29CD	 # [4]
29D3		
29D6	29D7	 # [2]
29DD	29E0	 # [4]
29E2		
29E6	29E7	 # [2]
29EA	29F3	 # [10]
29FA	29FB	 # [2]
29FE	2A09	 # [12]
2A1D		
2A22	2A23	 # [2]
2A25		
2A27	2A28	 # [2]
2A2A		
2A2F	2A33	 # [5]
2A36	2A3B	 # [6]
2A3F	2A56	 # [24]
2A59	2A63	 # [11]
2A66	2A69	 # [4]
2A6E		
2A71	2A72	 # [2]
2A75	2A78	 # [4]
2AA4	2AA5	 # [2]
2AAE		
2AD7	2ADB	 # [5]
2ADD		
2ADF	2AE1	 # [3]
2AE7	2AEB	 # [5]
2AEF	2AF2	 # [4]
2AF4	2AF6	 # [3]
2AFC		
2AFE	2E01	 # [772]
2E06	2E08	 # [3]
2E0B		
2E0E	2E1B	 # [14]
2E1E	2E1F	 # [2]
2E2A	3007	 # [478]
3012	3013	 # [2]
301C	FE58	 # [52_797]
FE5F	FE63	 # [5]
FE66	FF07	 # [162]
FF0A	FF1B	 # [18]
FF1D		
FF1F	FF3A	 # [28]
FF3C		
FF3E	FF5A	 # [29]
FF5C		
FF5E		
FF61		
FF64	1D6DA	 # [55_159]
1D6DC	1D714	 # [57]
1D716	1D74E	 # [57]
1D750	1D788	 # [57]
1D78A	1D7C2	 # [57]
1D7C4	10FFFF	 # [993_340]
END
