# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 1_111_352 code points in Unicode Version 5.2.0 that
# match any of the following regular expression constructs:
# 
#         \p{Pattern_Syntax=No}
#         \p{Pat_Syn=N}
#         \p{Is_Pattern_Syntax=F}
#         \p{Is_Pat_Syn=False}
# 
#         \P{Pattern_Syntax}
#         \P{Is_Pattern_Syntax}
#         \P{Pat_Syn}
#         \P{Is_Pat_Syn}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Pat_Syn: No}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0000	0020	 # [33]
0030	0039	 # [10]
0041	005A	 # [26]
005F		
0061	007A	 # [26]
007F	00A0	 # [34]
00A8		
00AA		
00AD		
00AF		
00B2	00B5	 # [4]
00B7	00BA	 # [4]
00BC	00BE	 # [3]
00C0	00D6	 # [23]
00D8	00F6	 # [31]
00F8	200F	 # [7960]
2028	202F	 # [8]
203F	2040	 # [2]
2054		
205F	218F	 # [305]
2460	24FF	 # [160]
2776	2793	 # [30]
2C00	2DFF	 # [512]
2E80	3000	 # [385]
3004	3007	 # [4]
3021	302F	 # [15]
3031	FD3D	 # [52_493]
FD40	FE44	 # [261]
FE47	10FFFF	 # [1_049_017]
END
