# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 84 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Numeric_Value=5}
#         \p{Nv=5}
#         \p{Is_Numeric_Value=5}
#         \p{Is_Nv=5}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Nv: 5}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0035		
0665		
06F5		
07C5		
096B		
09EB		
0A6B		
0AEB		
0B6B		
0BEB		
0C6B		
0CEB		
0D6B		
0E55		
0ED5		
0F25		
1045		
1095		
136D		
17E5		
17F5		
1815		
194B		
19D5		
1A85		
1A95		
1B55		
1BB5		
1C45		
1C55		
2075		
2085		
2164		
2174		
2464		
2478		
248C		
24F9		
277A		
2784		
278E		
3025		
3224		
3284		
3405		
382A		
4E94		
4F0D		
A625		
A6EA		
A8D5		
A905		
A9D5		
AA55		
ABF5		
FF15		
1010B		
10143		
10148		
1014F		
1015F		
10173		
10321		
104A5		
10E64		
12403		
1240A		
12410		
12419		
12422		
12427		
12431		
12439		
1244D		
12454	12455	 # [2]
1D364		
1D7D3		
1D7DD		
1D7E7		
1D7F1		
1D7FB		
1F106		
20121		
END
