# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 662 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Line_Break=Complex_Context}
#         \p{Lb=SA}
#         \p{Is_Line_Break=Complex_Context}
#         \p{Is_Lb=SA}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Lb: Complex_Context}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0E01	0E3A	 # [58]
0E40	0E4E	 # [15]
0E81	0E82	 # [2]
0E84		
0E87	0E88	 # [2]
0E8A		
0E8D		
0E94	0E97	 # [4]
0E99	0E9F	 # [7]
0EA1	0EA3	 # [3]
0EA5		
0EA7		
0EAA	0EAB	 # [2]
0EAD	0EB9	 # [13]
0EBB	0EBD	 # [3]
0EC0	0EC4	 # [5]
0EC6		
0EC8	0ECD	 # [6]
0EDC	0EDD	 # [2]
1000	103F	 # [64]
1050	108F	 # [64]
109A	109F	 # [6]
1780	17D3	 # [84]
17D7		
17DC	17DD	 # [2]
1950	196D	 # [30]
1970	1974	 # [5]
1980	19AB	 # [44]
19B0	19C9	 # [26]
19DE	19DF	 # [2]
1A20	1A5E	 # [63]
1A60	1A7C	 # [29]
1AA0	1AAD	 # [14]
AA60	AA7B	 # [28]
AA80	AAC2	 # [67]
AADB	AADF	 # [5]
END
