# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 77 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Line_Break=Nonstarter}
#         \p{Lb=NS}
#         \p{Is_Line_Break=Nonstarter}
#         \p{Is_Lb=NS}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Lb: Nonstarter}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
17D6		
203C	203D	 # [2]
2047	2049	 # [3]
3005		
301C		
303B	303C	 # [2]
3041		
3043		
3045		
3047		
3049		
3063		
3083		
3085		
3087		
308E		
3095	3096	 # [2]
309B	309E	 # [4]
30A0	30A1	 # [2]
30A3		
30A5		
30A7		
30A9		
30C3		
30E3		
30E5		
30E7		
30EE		
30F5	30F6	 # [2]
30FB	30FE	 # [4]
31F0	31FF	 # [16]
A015		
FE54	FE55	 # [2]
FF1A	FF1B	 # [2]
FF65		
FF67	FF70	 # [10]
FF9E	FF9F	 # [2]
END
