# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# 'D' below means that this form is deprecated.  Consult perluniprops.pod
# 
# This file returns the 1_114_089 code points in Unicode Version 5.2.0 that
# match any of the following regular expression constructs:
# 
# D       \p{Other_Grapheme_Extend=No}
# D       \p{OGr_Ext=N}
# D       \p{Is_Other_Grapheme_Extend=F}
# D       \p{Is_OGr_Ext=False}
# 
# D       \P{Other_Grapheme_Extend}
# D       \P{Is_Other_Grapheme_Extend}
# D       \P{OGr_Ext}
# D       \P{Is_OGr_Ext}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_OGr_Ext: No}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0000	09BD	 # [2494]
09BF	09D6	 # [24]
09D8	0B3D	 # [358]
0B3F	0B56	 # [24]
0B58	0BBD	 # [102]
0BBF	0BD6	 # [24]
0BD8	0CC1	 # [234]
0CC3	0CD4	 # [18]
0CD7	0D3D	 # [103]
0D3F	0D56	 # [24]
0D58	0DCE	 # [119]
0DD0	0DDE	 # [15]
0DE0	200B	 # [4652]
200E	FF9D	 # [57_232]
FFA0	1D164	 # [53_701]
1D166	1D16D	 # [8]
1D173	10FFFF	 # [994_957]
END
