# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 1624 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Age=5.1}
#         \p{Is_Age=5.1}
# 
#     Meaning: Code point's usage was introduced in version 5.1
# 
#     Note: See also Property 'Present_In'
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Age: 5.1}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0370	0373	 # [4]
0376	0377	 # [2]
03CF		
0487		
0514	0523	 # [16]
0606	060A	 # [5]
0616	061A	 # [5]
063B	063F	 # [5]
076E	077F	 # [18]
0971	0972	 # [2]
0A51		
0A75		
0B44		
0B62	0B63	 # [2]
0BD0		
0C3D		
0C58	0C59	 # [2]
0C62	0C63	 # [2]
0C78	0C7F	 # [8]
0D3D		
0D44		
0D62	0D63	 # [2]
0D70	0D75	 # [6]
0D79	0D7F	 # [7]
0F6B	0F6C	 # [2]
0FCE		
0FD2	0FD4	 # [3]
1022		
1028		
102B		
1033	1035	 # [3]
103A	103F	 # [6]
105A	1099	 # [64]
109E	109F	 # [2]
18AA		
1B80	1BAA	 # [43]
1BAE	1BB9	 # [12]
1C00	1C37	 # [56]
1C3B	1C49	 # [15]
1C4D	1C7F	 # [51]
1DCB	1DE6	 # [28]
1E9C	1E9F	 # [4]
1EFA	1EFF	 # [6]
2064		
20F0		
214F		
2185	2188	 # [4]
269D		
26B3	26BC	 # [10]
26C0	26C3	 # [4]
27CC		
27EC	27EF	 # [4]
2B1B	2B1F	 # [5]
2B24	2B4C	 # [41]
2B50	2B54	 # [5]
2C6D	2C6F	 # [3]
2C71	2C73	 # [3]
2C78	2C7D	 # [6]
2DE0	2DFF	 # [32]
2E18	2E1B	 # [4]
2E1E	2E30	 # [19]
312D		
31D0	31E3	 # [20]
9FBC	9FC3	 # [8]
A500	A62B	 # [300]
A640	A65F	 # [32]
A662	A673	 # [18]
A67C	A697	 # [28]
A71B	A71F	 # [5]
A722	A78C	 # [107]
A7FB	A7FF	 # [5]
A880	A8C4	 # [69]
A8CE	A8D9	 # [12]
A900	A953	 # [84]
A95F		
AA00	AA36	 # [55]
AA40	AA4D	 # [14]
AA50	AA59	 # [10]
AA5C	AA5F	 # [4]
FE24	FE26	 # [3]
10190	1019B	 # [12]
101D0	101FD	 # [46]
10280	1029C	 # [29]
102A0	102D0	 # [49]
10920	10939	 # [26]
1093F		
1D129		
1F000	1F02B	 # [44]
1F030	1F093	 # [100]
END
