# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 71 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Numeric_Value=8}
#         \p{Nv=8}
#         \p{Is_Numeric_Value=8}
#         \p{Is_Nv=8}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Nv: 8}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0038		
0668		
06F8		
07C8		
096E		
09EE		
0A6E		
0AEE		
0B6E		
0BEE		
0C6E		
0CEE		
0D6E		
0E58		
0ED8		
0F28		
1048		
1098		
1370		
17E8		
17F8		
1818		
194E		
19D8		
1A88		
1A98		
1B58		
1BB8		
1C48		
1C58		
2078		
2088		
2167		
2177		
2467		
247B		
248F		
24FC		
277D		
2787		
2791		
3028		
3227		
3287		
516B		
634C		
A628		
A6ED		
A8D8		
A908		
A9D8		
AA58		
ABF8		
FF18		
1010E		
104A8		
10E67		
12406		
1240D		
12413		
1241C		
1242A		
12444	12445	 # [2]
1D367		
1D7D6		
1D7E0		
1D7EA		
1D7F4		
1D7FE		
1F109		
END
