# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 1_114_084 code points in Unicode Version 5.2.0 that
# match any of the following regular expression constructs:
# 
#         \p{Extender=No}
#         \p{Ext=N}
#         \p{Is_Extender=F}
#         \p{Is_Ext=False}
# 
#         \P{Extender}
#         \P{Is_Extender}
#         \P{Ext}
#         \P{Is_Ext}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Ext: No}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0000	00B6	 # [183]
00B8	02CF	 # [536]
02D2	063F	 # [878]
0641	07F9	 # [441]
07FB	0E45	 # [1611]
0E47	0EC5	 # [127]
0EC7	1842	 # [2428]
1844	1AA6	 # [611]
1AA8	1C35	 # [398]
1C37	1C7A	 # [68]
1C7C	3004	 # [5001]
3006	3030	 # [43]
3036	309C	 # [103]
309F	30FB	 # [93]
30FF	A014	 # [28_438]
A016	A60B	 # [1526]
A60D	A9CE	 # [962]
A9D0	AA6F	 # [160]
AA71	AADC	 # [108]
AADE	FF6F	 # [21_650]
FF71	10FFFF	 # [1_048_719]
END
