# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 75 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Numeric_Value=7}
#         \p{Nv=7}
#         \p{Is_Numeric_Value=7}
#         \p{Is_Nv=7}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Nv: 7}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0037		
0667		
06F7		
07C7		
096D		
09ED		
0A6D		
0AED		
0B6D		
0BED		
0C6D		
0CED		
0D6D		
0E57		
0ED7		
0F27		
1047		
1097		
136F		
17E7		
17F7		
1817		
194D		
19D7		
1A87		
1A97		
1B57		
1BB7		
1C47		
1C57		
2077		
2087		
2166		
2176		
2466		
247A		
248E		
24FB		
277C		
2786		
2790		
3027		
3226		
3286		
3B4D		
4E03		
67D2		
6F06		
A627		
A6EC		
A8D7		
A907		
A9D7		
AA57		
ABF7		
FF17		
1010D		
104A7		
10E66		
12405		
1240C		
12412		
1241B		
12429		
12441	12443	 # [3]
1D366		
1D7D5		
1D7DF		
1D7E9		
1D7F3		
1D7FD		
1F108		
20001		
END
