# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 1_114_087 code points in Unicode Version 5.2.0 that
# match any of the following regular expression constructs:
# 
#         \p{Dash=No}
#         \p{Is_Dash=N}
#         \p{Dash=F}
#         \p{Is_Dash=False}
# 
#         \P{Dash}
#         \P{Is_Dash}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Dash: No}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0000	002C	 # [45]
002E	0589	 # [1372]
058B	05BD	 # [51]
05BF	13FF	 # [3649]
1401	1805	 # [1029]
1807	200F	 # [2057]
2016	2052	 # [61]
2054	207A	 # [39]
207C	208A	 # [15]
208C	2211	 # [390]
2213	2E16	 # [3076]
2E18	2E19	 # [2]
2E1B	301B	 # [513]
301D	302F	 # [19]
3031	309F	 # [111]
30A1	FE30	 # [52_624]
FE33	FE57	 # [37]
FE59	FE62	 # [10]
FE64	FF0C	 # [169]
FF0E	10FFFF	 # [1_048_818]
END
