# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 6648 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Age=5.2}
#         \p{Is_Age=5.2}
# 
#     Meaning: Code point's usage was introduced in version 5.2
# 
#     Note: See also Property 'Present_In'
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Age: 5.2}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0524	0525	 # [2]
0800	082D	 # [46]
0830	083E	 # [15]
0900		
094E		
0955		
0979	097A	 # [2]
09FB		
0FD5	0FD8	 # [4]
109A	109D	 # [4]
115A	115E	 # [5]
11A3	11A7	 # [5]
11FA	11FF	 # [6]
1400		
1677	167F	 # [9]
18B0	18F5	 # [70]
19AA	19AB	 # [2]
19DA		
1A20	1A5E	 # [63]
1A60	1A7C	 # [29]
1A7F	1A89	 # [11]
1A90	1A99	 # [10]
1AA0	1AAD	 # [14]
1CD0	1CF2	 # [35]
1DFD		
20B6	20B8	 # [3]
2150	2152	 # [3]
2189		
23E8		
269E	269F	 # [2]
26BD	26BF	 # [3]
26C4	26CD	 # [10]
26CF	26E1	 # [19]
26E3		
26E8	26FF	 # [24]
2757		
2B55	2B59	 # [5]
2C70		
2C7E	2C7F	 # [2]
2CEB	2CF1	 # [7]
2E31		
3244	324F	 # [12]
9FC4	9FCB	 # [8]
A4D0	A4FF	 # [48]
A6A0	A6F7	 # [88]
A830	A839	 # [10]
A8E0	A8FB	 # [28]
A960	A97C	 # [29]
A980	A9CD	 # [78]
A9CF	A9D9	 # [11]
A9DE	A9DF	 # [2]
AA60	AA7B	 # [28]
AA80	AAC2	 # [67]
AADB	AADF	 # [5]
ABC0	ABED	 # [46]
ABF0	ABF9	 # [10]
D7B0	D7C6	 # [23]
D7CB	D7FB	 # [49]
FA6B	FA6D	 # [3]
10840	10855	 # [22]
10857	1085F	 # [9]
1091A	1091B	 # [2]
10A60	10A7F	 # [32]
10B00	10B35	 # [54]
10B39	10B55	 # [29]
10B58	10B72	 # [27]
10B78	10B7F	 # [8]
10C00	10C48	 # [73]
10E60	10E7E	 # [31]
11080	110C1	 # [66]
13000	1342E	 # [1071]
1F100	1F10A	 # [11]
1F110	1F12E	 # [31]
1F131		
1F13D		
1F13F		
1F142		
1F146		
1F14A	1F14E	 # [5]
1F157		
1F15F		
1F179		
1F17B	1F17C	 # [2]
1F17F		
1F18A	1F18D	 # [4]
1F190		
1F200		
1F210	1F231	 # [34]
1F240	1F248	 # [9]
2A700	2B734	 # [4149]
END
