# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 276 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{General_Category=Spacing_Mark}
#         \p{Gc=Mc}
#         \p{Category=Spacing_Mark}
#         \p{Is_General_Category=Mc}
#         \p{Is_Gc=Spacing_Mark}
#         \p{Is_Category=Mc}
# 
#         \p{Spacing_Mark}
#         \p{Is_Spacing_Mark}
#         \p{Mc}
#         \p{Is_Mc}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Category: Spacing_Mark}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0903		
093E	0940	 # [3]
0949	094C	 # [4]
094E		
0982	0983	 # [2]
09BE	09C0	 # [3]
09C7	09C8	 # [2]
09CB	09CC	 # [2]
09D7		
0A03		
0A3E	0A40	 # [3]
0A83		
0ABE	0AC0	 # [3]
0AC9		
0ACB	0ACC	 # [2]
0B02	0B03	 # [2]
0B3E		
0B40		
0B47	0B48	 # [2]
0B4B	0B4C	 # [2]
0B57		
0BBE	0BBF	 # [2]
0BC1	0BC2	 # [2]
0BC6	0BC8	 # [3]
0BCA	0BCC	 # [3]
0BD7		
0C01	0C03	 # [3]
0C41	0C44	 # [4]
0C82	0C83	 # [2]
0CBE		
0CC0	0CC4	 # [5]
0CC7	0CC8	 # [2]
0CCA	0CCB	 # [2]
0CD5	0CD6	 # [2]
0D02	0D03	 # [2]
0D3E	0D40	 # [3]
0D46	0D48	 # [3]
0D4A	0D4C	 # [3]
0D57		
0D82	0D83	 # [2]
0DCF	0DD1	 # [3]
0DD8	0DDF	 # [8]
0DF2	0DF3	 # [2]
0F3E	0F3F	 # [2]
0F7F		
102B	102C	 # [2]
1031		
1038		
103B	103C	 # [2]
1056	1057	 # [2]
1062	1064	 # [3]
1067	106D	 # [7]
1083	1084	 # [2]
1087	108C	 # [6]
108F		
109A	109C	 # [3]
17B6		
17BE	17C5	 # [8]
17C7	17C8	 # [2]
1923	1926	 # [4]
1929	192B	 # [3]
1930	1931	 # [2]
1933	1938	 # [6]
19B0	19C0	 # [17]
19C8	19C9	 # [2]
1A19	1A1B	 # [3]
1A55		
1A57		
1A61		
1A63	1A64	 # [2]
1A6D	1A72	 # [6]
1B04		
1B35		
1B3B		
1B3D	1B41	 # [5]
1B43	1B44	 # [2]
1B82		
1BA1		
1BA6	1BA7	 # [2]
1BAA		
1C24	1C2B	 # [8]
1C34	1C35	 # [2]
1CE1		
1CF2		
A823	A824	 # [2]
A827		
A880	A881	 # [2]
A8B4	A8C3	 # [16]
A952	A953	 # [2]
A983		
A9B4	A9B5	 # [2]
A9BA	A9BB	 # [2]
A9BD	A9C0	 # [4]
AA2F	AA30	 # [2]
AA33	AA34	 # [2]
AA4D		
AA7B		
ABE3	ABE4	 # [2]
ABE6	ABE7	 # [2]
ABE9	ABEA	 # [2]
ABEC		
11082		
110B0	110B2	 # [3]
110B7	110B8	 # [2]
1D165	1D166	 # [2]
1D16D	1D172	 # [6]
END
