# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 81 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Composition_Exclusion=Yes}
#         \p{CE=Y}
#         \p{Is_Composition_Exclusion=T}
#         \p{Is_CE=True}
# 
#         \p{Composition_Exclusion}
#         \p{Is_Composition_Exclusion}
#         \p{CE}
#         \p{Is_CE}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_CE: Yes}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0958	095F	 # [8]
09DC	09DD	 # [2]
09DF		
0A33		
0A36		
0A59	0A5B	 # [3]
0A5E		
0B5C	0B5D	 # [2]
0F43		
0F4D		
0F52		
0F57		
0F5C		
0F69		
0F76		
0F78		
0F93		
0F9D		
0FA2		
0FA7		
0FAC		
0FB9		
2ADC		
FB1D		
FB1F		
FB2A	FB36	 # [13]
FB38	FB3C	 # [5]
FB3E		
FB40	FB41	 # [2]
FB43	FB44	 # [2]
FB46	FB4E	 # [9]
1D15E	1D164	 # [7]
1D1BB	1D1C0	 # [6]
END
