# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 96 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Numeric_Value=3}
#         \p{Nv=3}
#         \p{Is_Numeric_Value=3}
#         \p{Is_Nv=3}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Nv: 3}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0033		
00B3		
0663		
06F3		
07C3		
0969		
09E9		
0A69		
0AE9		
0B69		
0BE9		
0C69		
0C7B		
0C7E		
0CE9		
0D69		
0E53		
0ED3		
0F23		
1043		
1093		
136B		
17E3		
17F3		
1813		
1949		
19D3		
1A83		
1A93		
1B53		
1BB3		
1C43		
1C53		
2083		
2162		
2172		
2462		
2476		
248A		
24F7		
2778		
2782		
278C		
3023		
3194		
3222		
3282		
4E09		
4EE8		
53C1	53C4	 # [4]
5F0E		
A623		
A6E8		
A8D3		
A903		
A9D3		
AA53		
ABF3		
F96B		
FF13		
10109		
104A3		
1085A		
1091B		
10A42		
10B5A		
10B7A		
10E62		
12401		
12408		
12417		
12420		
12424	12425	 # [2]
1242E	1242F	 # [2]
12436	12437	 # [2]
1243A	1243B	 # [2]
1244B		
12451		
1D362		
1D7D1		
1D7DB		
1D7E5		
1D7EF		
1D7F9		
1F104		
20AFD		
20B19		
22998		
23B1B		
END
