# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 1_114_046 code points in Unicode Version 5.2.0 that
# match any of the following regular expression constructs:
# 
#         \p{STerm=No}
#         \p{Is_STerm=N}
#         \p{STerm=F}
#         \p{Is_STerm=False}
# 
#         \P{STerm}
#         \P{Is_STerm}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_STerm: No}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0000	0020	 # [33]
0022	002D	 # [12]
002F	003E	 # [16]
0040	055B	 # [1308]
055D		
055F	0588	 # [42]
058A	061E	 # [149]
0620	06D3	 # [180]
06D5	06FF	 # [43]
0703	07F8	 # [246]
07FA	0963	 # [362]
0966	1049	 # [1764]
104C	1361	 # [790]
1363	1366	 # [4]
1369	166D	 # [773]
166F	1802	 # [404]
1804	1808	 # [5]
180A	1943	 # [314]
1946	1B59	 # [532]
1B5C	1B5D	 # [2]
1B60	1C3A	 # [219]
1C3D	1C7D	 # [65]
1C80	203B	 # [956]
203E	2046	 # [9]
204A	2E2D	 # [3556]
2E2F	3001	 # [467]
3003	A4FE	 # [29_948]
A500	A60D	 # [270]
A610	A6F2	 # [227]
A6F4	A6F6	 # [3]
A6F8	A875	 # [382]
A878	A8CD	 # [86]
A8D0	A92E	 # [95]
A930	A9C7	 # [152]
A9CA	AA5C	 # [147]
AA60	ABEA	 # [395]
ABEC	FE51	 # [21_094]
FE53	FE55	 # [3]
FE58	FF00	 # [169]
FF02	FF0D	 # [12]
FF0F	FF1E	 # [16]
FF20	FF60	 # [65]
FF62	110BD	 # [4444]
110C2	10FFFF	 # [1_044_286]
END
