# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 118 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Numeric_Type=Digit}
#         \p{Nt=Di}
#         \p{Is_Numeric_Type=Digit}
#         \p{Is_Nt=Di}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Nt: Digit}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
00B2	00B3	 # [2]
00B9		
1369	1371	 # [9]
2070		
2074	2079	 # [6]
2080	2089	 # [10]
2460	2468	 # [9]
2474	247C	 # [9]
2488	2490	 # [9]
24EA		
24F5	24FD	 # [9]
24FF		
2776	277E	 # [9]
2780	2788	 # [9]
278A	2792	 # [9]
10A40	10A43	 # [4]
10E60	10E68	 # [9]
1F100	1F10A	 # [11]
END
