# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 161_775 code points in Unicode Version 5.2.0 that
# match any of the following regular expression constructs:
# 
#         \p{Line_Break=Ideographic}
#         \p{Lb=ID}
#         \p{Is_Line_Break=Ideographic}
#         \p{Is_Lb=ID}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Lb: Ideographic}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
2E80	2E99	 # [26]
2E9B	2EF3	 # [89]
2F00	2FD5	 # [214]
2FF0	2FFB	 # [12]
3000		
3003	3004	 # [2]
3006	3007	 # [2]
3012	3013	 # [2]
3020	3029	 # [10]
3030	303A	 # [11]
303D	303F	 # [3]
3042		
3044		
3046		
3048		
304A	3062	 # [25]
3064	3082	 # [31]
3084		
3086		
3088	308D	 # [6]
308F	3094	 # [6]
309F		
30A2		
30A4		
30A6		
30A8		
30AA	30C2	 # [25]
30C4	30E2	 # [31]
30E4		
30E6		
30E8	30ED	 # [6]
30EF	30F4	 # [6]
30F7	30FA	 # [4]
30FF		
3105	312D	 # [41]
3131	318E	 # [94]
3190	31B7	 # [40]
31C0	31E3	 # [36]
3200	321E	 # [31]
3220	3247	 # [40]
3250	32FE	 # [175]
3300	4DBF	 # [6848]
4E00	A014	 # [21_013]
A016	A48C	 # [1143]
A490	A4C6	 # [55]
F900	FAFF	 # [512]
FE30	FE34	 # [5]
FE45	FE46	 # [2]
FE49	FE4F	 # [7]
FE51		
FE58		
FE5F	FE66	 # [8]
FE68		
FE6B		
FF02	FF03	 # [2]
FF06	FF07	 # [2]
FF0A	FF0B	 # [2]
FF0D		
FF0F	FF19	 # [11]
FF1C	FF1E	 # [3]
FF20	FF3A	 # [27]
FF3C		
FF3E	FF5A	 # [29]
FF5C		
FF5E		
FFE2	FFE4	 # [3]
1F200		
1F210	1F231	 # [34]
1F240	1F248	 # [9]
20000	2FFFD	 # [65_534]
30000	3FFFD	 # [65_534]
END
