# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 644 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Line_Break=Ambiguous}
#         \p{Lb=AI}
#         \p{Is_Line_Break=Ambiguous}
#         \p{Is_Lb=AI}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Lb: Ambiguous}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
00A7	00A8	 # [2]
00AA		
00B2	00B3	 # [2]
00B6	00BA	 # [5]
00BC	00BE	 # [3]
00D7		
00F7		
02C7		
02C9	02CB	 # [3]
02CD		
02D0		
02D8	02DB	 # [4]
02DD		
2015	2016	 # [2]
2020	2021	 # [2]
203B		
2074		
207F		
2081	2084	 # [4]
2105		
2113		
2121	2122	 # [2]
212B		
2154	2155	 # [2]
215B		
215E		
2160	216B	 # [12]
2170	2179	 # [10]
2189		
2190	2199	 # [10]
21D2		
21D4		
2200		
2202	2203	 # [2]
2207	2208	 # [2]
220B		
220F		
2211		
2215		
221A		
221D	2220	 # [4]
2223		
2225		
2227	222C	 # [6]
222E		
2234	2237	 # [4]
223C	223D	 # [2]
2248		
224C		
2252		
2260	2261	 # [2]
2264	2267	 # [4]
226A	226B	 # [2]
226E	226F	 # [2]
2282	2283	 # [2]
2286	2287	 # [2]
2295		
2299		
22A5		
22BF		
2312		
2460	24FE	 # [159]
2500	254B	 # [76]
2550	2574	 # [37]
2580	258F	 # [16]
2592	2595	 # [4]
25A0	25A1	 # [2]
25A3	25A9	 # [7]
25B2	25B3	 # [2]
25B6	25B7	 # [2]
25BC	25BD	 # [2]
25C0	25C1	 # [2]
25C6	25C8	 # [3]
25CB		
25CE	25D1	 # [4]
25E2	25E5	 # [4]
25EF		
2605	2606	 # [2]
2609		
260E	260F	 # [2]
2614	2617	 # [4]
261C		
261E		
2640		
2642		
2660	2661	 # [2]
2663	2665	 # [3]
2667	266A	 # [4]
266C	266D	 # [2]
266F		
269E	269F	 # [2]
26BE	26BF	 # [2]
26C4	26CD	 # [10]
26CF	26E1	 # [19]
26E3		
26E8	26FF	 # [24]
2757		
2776	2793	 # [30]
2B55	2B59	 # [5]
3248	324F	 # [8]
FFFD		
1F100	1F10A	 # [11]
1F110	1F12D	 # [30]
1F131		
1F13D		
1F13F		
1F142		
1F146		
1F14A	1F14E	 # [5]
1F157		
1F15F		
1F179		
1F17B	1F17C	 # [2]
1F17F		
1F18A	1F18D	 # [4]
1F190		
END
