# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 1_038_704 code points in Unicode Version 5.2.0 that
# match any of the following regular expression constructs:
# 
#         \p{Ideographic=No}
#         \p{Ideo=N}
#         \p{Is_Ideographic=F}
#         \p{Is_Ideo=False}
# 
#         \P{Ideographic}
#         \P{Is_Ideographic}
#         \P{Ideo}
#         \P{Is_Ideo}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Ideo: No}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0000	3005	 # [12_294]
3008	3020	 # [25]
302A	3037	 # [14]
303B	33FF	 # [965]
4DB6	4DFF	 # [74]
9FCC	F8FF	 # [22_836]
FA2E	FA2F	 # [2]
FA6E	FA6F	 # [2]
FADA	1FFFF	 # [66_854]
2A6D7	2A6FF	 # [41]
2B735	2F7FF	 # [16_587]
2FA1E	10FFFF	 # [919_010]
END
