# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 4016 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Bidi_Class=Boundary_Neutral}
#         \p{Bc=BN}
#         \p{Is_Bidi_Class=Boundary_Neutral}
#         \p{Is_Bc=BN}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Bc: Boundary_Neutral}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0000	0008	 # [9]
000E	001B	 # [14]
007F	0084	 # [6]
0086	009F	 # [26]
00AD		
070F		
200B	200D	 # [3]
2060	206F	 # [16]
FDD0	FDEF	 # [32]
FEFF		
FFF0	FFF8	 # [9]
FFFE	FFFF	 # [2]
1D173	1D17A	 # [8]
1FFFE	1FFFF	 # [2]
2FFFE	2FFFF	 # [2]
3FFFE	3FFFF	 # [2]
4FFFE	4FFFF	 # [2]
5FFFE	5FFFF	 # [2]
6FFFE	6FFFF	 # [2]
7FFFE	7FFFF	 # [2]
8FFFE	8FFFF	 # [2]
9FFFE	9FFFF	 # [2]
AFFFE	AFFFF	 # [2]
BFFFE	BFFFF	 # [2]
CFFFE	CFFFF	 # [2]
DFFFE	E00FF	 # [258]
E01F0	E0FFF	 # [3600]
EFFFE	EFFFF	 # [2]
FFFFE	FFFFF	 # [2]
10FFFE	10FFFF	 # [2]
END
