# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 4441 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Bidi_Class=Right_To_Left}
#         \p{Bc=R}
#         \p{Is_Bidi_Class=Right_To_Left}
#         \p{Is_Bc=R}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Bc: Right_To_Left}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0590		
05BE		
05C0		
05C3		
05C6		
05C8	05FF	 # [56]
07C0	07EA	 # [43]
07F4	07F5	 # [2]
07FA	0815	 # [28]
081A		
0824		
0828		
082E	08FF	 # [210]
200F		
FB1D		
FB1F	FB28	 # [10]
FB2A	FB4F	 # [38]
10800	1091E	 # [287]
10920	10A00	 # [225]
10A04		
10A07	10A0B	 # [5]
10A10	10A37	 # [40]
10A3B	10A3E	 # [4]
10A40	10B38	 # [249]
10B40	10E5F	 # [800]
10E7F	10FFF	 # [385]
1E800	1EFFF	 # [2048]
END
