# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 171 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Decomposition_Type=Initial}
#         \p{Dt=Init}
#         \p{Is_Decomposition_Type=Initial}
#         \p{Is_Dt=Init}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Dt: Initial}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
FB54		
FB58		
FB5C		
FB60		
FB64		
FB68		
FB6C		
FB70		
FB74		
FB78		
FB7C		
FB80		
FB90		
FB94		
FB98		
FB9C		
FBA2		
FBA8		
FBAC		
FBD5		
FBE6		
FBE8		
FBF8		
FBFB		
FBFE		
FC97	FCDE	 # [72]
FD2D	FD33	 # [7]
FD50		
FD52	FD57	 # [6]
FD59		
FD5C	FD5D	 # [2]
FD60	FD61	 # [2]
FD63		
FD65		
FD68		
FD6B		
FD6D		
FD70		
FD72	FD73	 # [2]
FD77		
FD7D		
FD83		
FD86		
FD88	FD8A	 # [3]
FD8C	FD8F	 # [4]
FD92	FD95	 # [4]
FD98		
FD9D		
FDB4	FDB5	 # [2]
FDB8		
FDBA		
FDC3	FDC5	 # [3]
FE8B		
FE91		
FE97		
FE9B		
FE9F		
FEA3		
FEA7		
FEB3		
FEB7		
FEBB		
FEBF		
FEC3		
FEC7		
FECB		
FECF		
FED3		
FED7		
FEDB		
FEDF		
FEE3		
FEE7		
FEEB		
FEF3		
END
