# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 202 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{General_Category=Modifier_Letter}
#         \p{Gc=Lm}
#         \p{Category=Modifier_Letter}
#         \p{Is_General_Category=Lm}
#         \p{Is_Gc=Modifier_Letter}
#         \p{Is_Category=Lm}
# 
#         \p{Modifier_Letter}
#         \p{Is_Modifier_Letter}
#         \p{Lm}
#         \p{Is_Lm}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Category: Modifier_Letter}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
02B0	02C1	 # [18]
02C6	02D1	 # [12]
02E0	02E4	 # [5]
02EC		
02EE		
0374		
037A		
0559		
0640		
06E5	06E6	 # [2]
07F4	07F5	 # [2]
07FA		
081A		
0824		
0828		
0971		
0E46		
0EC6		
10FC		
17D7		
1843		
1AA7		
1C78	1C7D	 # [6]
1D2C	1D61	 # [54]
1D78		
1D9B	1DBF	 # [37]
2071		
207F		
2090	2094	 # [5]
2C7D		
2D6F		
2E2F		
3005		
3031	3035	 # [5]
303B		
309D	309E	 # [2]
30FC	30FE	 # [3]
A015		
A4F8	A4FD	 # [6]
A60C		
A67F		
A717	A71F	 # [9]
A770		
A788		
A9CF		
AA70		
AADD		
FF70		
FF9E	FF9F	 # [2]
END
