# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 1_039_718 code points in Unicode Version 5.2.0 that
# match any of the following regular expression constructs:
# 
#         \p{Unified_Ideograph=No}
#         \p{UIdeo=N}
#         \p{Is_Unified_Ideograph=F}
#         \p{Is_UIdeo=False}
# 
#         \P{Unified_Ideograph}
#         \P{Is_Unified_Ideograph}
#         \P{UIdeo}
#         \P{Is_UIdeo}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_UIdeo: No}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0000	33FF	 # [13_312]
4DB6	4DFF	 # [74]
9FCC	FA0D	 # [23_106]
FA10		
FA12		
FA15	FA1E	 # [10]
FA20		
FA22		
FA25	FA26	 # [2]
FA2A	1FFFF	 # [67_030]
2A6D7	2A6FF	 # [41]
2B735	10FFFF	 # [936_139]
END
