# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 2161 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Math=Yes}
#         \p{Is_Math=Y}
#         \p{Math=T}
#         \p{Is_Math=True}
# 
#         \p{Math}
#         \p{Is_Math}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Math: Yes}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
002B		
003C	003E	 # [3]
005E		
007C		
007E		
00AC		
00B1		
00D7		
00F7		
03D0	03D2	 # [3]
03D5		
03F0	03F1	 # [2]
03F4	03F6	 # [3]
0606	0608	 # [3]
2016		
2032	2034	 # [3]
2040		
2044		
2052		
2061	2064	 # [4]
207A	207E	 # [5]
208A	208E	 # [5]
20D0	20DC	 # [13]
20E1		
20E5	20E6	 # [2]
20EB	20EF	 # [5]
2102		
210A	2113	 # [10]
2115		
2119	211D	 # [5]
2124		
2128	2129	 # [2]
212C	212D	 # [2]
212F	2131	 # [3]
2133	2138	 # [6]
213C	2149	 # [14]
214B		
2190	21A7	 # [24]
21A9	21AE	 # [6]
21B0	21B1	 # [2]
21B6	21B7	 # [2]
21BC	21DB	 # [32]
21DD		
21E4	21E5	 # [2]
21F4	22FF	 # [268]
2308	230B	 # [4]
2320	2321	 # [2]
237C		
239B	23B5	 # [27]
23B7		
23D0		
23DC	23E2	 # [7]
25A0	25A1	 # [2]
25AE	25B7	 # [10]
25BC	25C1	 # [6]
25C6	25C7	 # [2]
25CA	25CB	 # [2]
25CF	25D3	 # [5]
25E2		
25E4		
25E7	25EC	 # [6]
25F8	25FF	 # [8]
2605	2606	 # [2]
2640		
2642		
2660	2663	 # [4]
266D	266F	 # [3]
27C0	27CA	 # [11]
27CC		
27D0	27FF	 # [48]
2900	2AFF	 # [512]
2B30	2B44	 # [21]
2B47	2B4C	 # [6]
FB29		
FE61	FE66	 # [6]
FE68		
FF0B		
FF1C	FF1E	 # [3]
FF3C		
FF3E		
FF5C		
FF5E		
FFE2		
FFE9	FFEC	 # [4]
1D400	1D454	 # [85]
1D456	1D49C	 # [71]
1D49E	1D49F	 # [2]
1D4A2		
1D4A5	1D4A6	 # [2]
1D4A9	1D4AC	 # [4]
1D4AE	1D4B9	 # [12]
1D4BB		
1D4BD	1D4C3	 # [7]
1D4C5	1D505	 # [65]
1D507	1D50A	 # [4]
1D50D	1D514	 # [8]
1D516	1D51C	 # [7]
1D51E	1D539	 # [28]
1D53B	1D53E	 # [4]
1D540	1D544	 # [5]
1D546		
1D54A	1D550	 # [7]
1D552	1D6A5	 # [340]
1D6A8	1D7CB	 # [292]
1D7CE	1D7FF	 # [50]
END
