# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 76 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Numeric_Value=6}
#         \p{Nv=6}
#         \p{Is_Numeric_Value=6}
#         \p{Is_Nv=6}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Nv: 6}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0036		
0666		
06F6		
07C6		
096C		
09EC		
0A6C		
0AEC		
0B6C		
0BEC		
0C6C		
0CEC		
0D6C		
0E56		
0ED6		
0F26		
1046		
1096		
136E		
17E6		
17F6		
1816		
194C		
19D6		
1A86		
1A96		
1B56		
1BB6		
1C46		
1C56		
2076		
2086		
2165		
2175		
2185		
2465		
2479		
248D		
24FA		
277B		
2785		
278F		
3026		
3225		
3285		
516D		
9646		
9678		
A626		
A6EB		
A8D6		
A906		
A9D6		
AA56		
ABF6		
F9D1		
F9D3		
FF16		
1010C		
104A6		
10E65		
12404		
1240B		
12411		
1241A		
12428		
12440		
1244E		
1D365		
1D7D4		
1D7DE		
1D7E8		
1D7F2		
1D7FC		
1F107		
20AEA		
END
