# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# 'D' below means that this form is deprecated.  Consult perluniprops.pod
# 
# This file returns the 1_113_353 code points in Unicode Version 5.2.0 that
# match any of the following regular expression constructs:
# 
# D       \p{Other_Alphabetic=No}
# D       \p{OAlpha=N}
# D       \p{Is_Other_Alphabetic=F}
# D       \p{Is_OAlpha=False}
# 
# D       \P{Other_Alphabetic}
# D       \P{Is_Other_Alphabetic}
# D       \P{OAlpha}
# D       \P{Is_OAlpha}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_OAlpha: No}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0000	0344	 # [837]
0346	05AF	 # [618]
05BE		
05C0		
05C3		
05C6		
05C8	060F	 # [72]
061B	064A	 # [48]
0658		
065F	066F	 # [17]
0671	06D5	 # [101]
06DD	06E0	 # [4]
06E5	06E6	 # [2]
06E9	06EC	 # [4]
06EE	0710	 # [35]
0712	072F	 # [30]
0740	07A5	 # [102]
07B1	0815	 # [101]
0818	081A	 # [3]
0824		
0828		
082D	08FF	 # [211]
0904	093D	 # [58]
094D		
094F	0954	 # [6]
0956	0961	 # [12]
0964	0980	 # [29]
0984	09BD	 # [58]
09C5	09C6	 # [2]
09C9	09CA	 # [2]
09CD	09D6	 # [10]
09D8	09E1	 # [10]
09E4	0A00	 # [29]
0A04	0A3D	 # [58]
0A43	0A46	 # [4]
0A49	0A4A	 # [2]
0A4D	0A50	 # [4]
0A52	0A6F	 # [30]
0A72	0A74	 # [3]
0A76	0A80	 # [11]
0A84	0ABD	 # [58]
0AC6		
0ACA		
0ACD	0AE1	 # [21]
0AE4	0B00	 # [29]
0B04	0B3D	 # [58]
0B45	0B46	 # [2]
0B49	0B4A	 # [2]
0B4D	0B55	 # [9]
0B58	0B61	 # [10]
0B64	0B81	 # [30]
0B83	0BBD	 # [59]
0BC3	0BC5	 # [3]
0BC9		
0BCD	0BD6	 # [10]
0BD8	0C00	 # [41]
0C04	0C3D	 # [58]
0C45		
0C49		
0C4D	0C54	 # [8]
0C57	0C61	 # [11]
0C64	0C81	 # [30]
0C84	0CBD	 # [58]
0CC5		
0CC9		
0CCD	0CD4	 # [8]
0CD7	0CE1	 # [11]
0CE4	0D01	 # [30]
0D04	0D3D	 # [58]
0D45		
0D49		
0D4D	0D56	 # [10]
0D58	0D61	 # [10]
0D64	0D81	 # [30]
0D84	0DCE	 # [75]
0DD5		
0DD7		
0DE0	0DF1	 # [18]
0DF4	0E30	 # [61]
0E32	0E33	 # [2]
0E3B	0E4C	 # [18]
0E4E	0EB0	 # [99]
0EB2	0EB3	 # [2]
0EBA		
0EBD	0ECC	 # [16]
0ECE	0F70	 # [163]
0F82	0F8F	 # [14]
0F98		
0FBD	102A	 # [110]
1037		
1039	103A	 # [2]
103F	1055	 # [23]
105A	105D	 # [4]
1061		
1063	1066	 # [4]
1069	1070	 # [8]
1075	1081	 # [13]
1087	109B	 # [21]
109E	135E	 # [705]
1360	1711	 # [946]
1714	1731	 # [30]
1734	1751	 # [30]
1754	1771	 # [30]
1774	17B5	 # [66]
17C9	18A8	 # [224]
18AA	191F	 # [118]
192C	192F	 # [4]
1939	19AF	 # [119]
19C1	19C7	 # [7]
19CA	1A16	 # [77]
1A1C	1A54	 # [57]
1A5F	1A60	 # [2]
1A75	1AFF	 # [139]
1B05	1B34	 # [48]
1B44	1B7F	 # [60]
1B83	1BA0	 # [30]
1BAA	1C23	 # [122]
1C36	1CF1	 # [188]
1CF3	24B5	 # [1987]
24EA	2DDF	 # [2294]
2E00	A822	 # [31_267]
A828	A87F	 # [88]
A882	A8B3	 # [50]
A8C4	A925	 # [98]
A92B	A946	 # [28]
A953	A97F	 # [45]
A984	A9B2	 # [47]
A9C0	AA28	 # [105]
AA37	AA42	 # [12]
AA44	AA4B	 # [8]
AA4E	AAAF	 # [98]
AAB1		
AAB5	AAB6	 # [2]
AAB9	AABD	 # [5]
AABF	ABE2	 # [292]
ABEB	FB1D	 # [20_275]
FB1F	10A00	 # [3810]
10A04		
10A07	10A0B	 # [5]
10A10	11081	 # [1650]
11083	110AF	 # [45]
110B9	10FFFF	 # [1_044_295]
END
