# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 142 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Decomposition_Type=Super}
#         \p{Dt=Sup}
#         \p{Is_Decomposition_Type=Super}
#         \p{Is_Dt=Sup}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Dt: Super}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
00AA		
00B2	00B3	 # [2]
00B9	00BA	 # [2]
02B0	02B8	 # [9]
02E0	02E4	 # [5]
10FC		
1D2C	1D2E	 # [3]
1D30	1D3A	 # [11]
1D3C	1D4D	 # [18]
1D4F	1D61	 # [19]
1D78		
1D9B	1DBF	 # [37]
2070	2071	 # [2]
2074	207F	 # [12]
2120		
2122		
2C7D		
2D6F		
3192	319F	 # [14]
A770		
END
