# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 144_521 code points in Unicode Version 5.2.0 that
# match any of the following regular expression constructs:
# 
#         \p{Age=2.0}
#         \p{Is_Age=2.0}
# 
#     Meaning: Code point's usage was introduced in version 2.0
# 
#     Note: See also Property 'Present_In'
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Age: 2.0}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0591	05A1	 # [17]
05A3	05AF	 # [13]
05C4		
0F00	0F47	 # [72]
0F49	0F69	 # [33]
0F71	0F8B	 # [27]
0F90	0F95	 # [6]
0F97		
0F99	0FAD	 # [21]
0FB1	0FB7	 # [7]
0FB9		
1E9B		
20AB		
AC00	D7A3	 # [11_172]
D800	DFFF	 # [2048]
1FFFE	1FFFF	 # [2]
2FFFE	2FFFF	 # [2]
3FFFE	3FFFF	 # [2]
4FFFE	4FFFF	 # [2]
5FFFE	5FFFF	 # [2]
6FFFE	6FFFF	 # [2]
7FFFE	7FFFF	 # [2]
8FFFE	8FFFF	 # [2]
9FFFE	9FFFF	 # [2]
AFFFE	AFFFF	 # [2]
BFFFE	BFFFF	 # [2]
CFFFE	CFFFF	 # [2]
DFFFE	DFFFF	 # [2]
EFFFE	10FFFF	 # [131_074]
END
