# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# 'X' below means that this form is discouraged.  Consult perluniprops.pod
# 
# This file returns the 864_192 code points in Unicode Version 5.2.0 that
# match any of the following regular expression constructs:
# 
#         \p{Block=No_Block}
#         \p{Blk=No_Block}
#         \p{Is_Block=No_Block}
#         \p{Is_Blk=No_Block}
# 
# X       \p{No_Block}
# X       \p{Is_No_Block}
#         \p{In_No_Block}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Blk: No_Block}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0840	08FF	 # [192]
1AB0	1AFF	 # [80]
1BC0	1BFF	 # [64]
1C80	1CCF	 # [80]
2FE0	2FEF	 # [16]
A9E0	A9FF	 # [32]
AAE0	ABBF	 # [224]
10200	1027F	 # [128]
102E0	102FF	 # [32]
10350	1037F	 # [48]
103E0	103FF	 # [32]
104B0	107FF	 # [848]
10860	108FF	 # [160]
10940	109FF	 # [192]
10A80	10AFF	 # [128]
10B80	10BFF	 # [128]
10C50	10E5F	 # [528]
10E80	1107F	 # [512]
110D0	11FFF	 # [3888]
12480	12FFF	 # [2944]
13430	1CFFF	 # [39_888]
1D250	1D2FF	 # [176]
1D380	1D3FF	 # [128]
1D800	1EFFF	 # [6144]
1F0A0	1F0FF	 # [96]
1F300	1FFFF	 # [3328]
2A6E0	2A6FF	 # [32]
2B740	2F7FF	 # [16_576]
2FA20	DFFFF	 # [722_400]
E0080	E00FF	 # [128]
E01F0	EFFFF	 # [65_040]
END
