# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 945 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{General_Category=Math_Symbol}
#         \p{Gc=Sm}
#         \p{Category=Math_Symbol}
#         \p{Is_General_Category=Sm}
#         \p{Is_Gc=Math_Symbol}
#         \p{Is_Category=Sm}
# 
#         \p{Math_Symbol}
#         \p{Is_Math_Symbol}
#         \p{Sm}
#         \p{Is_Sm}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Category: Math_Symbol}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
002B		
003C	003E	 # [3]
007C		
007E		
00AC		
00B1		
00D7		
00F7		
03F6		
0606	0608	 # [3]
2044		
2052		
207A	207C	 # [3]
208A	208C	 # [3]
2140	2144	 # [5]
214B		
2190	2194	 # [5]
219A	219B	 # [2]
21A0		
21A3		
21A6		
21AE		
21CE	21CF	 # [2]
21D2		
21D4		
21F4	22FF	 # [268]
2308	230B	 # [4]
2320	2321	 # [2]
237C		
239B	23B3	 # [25]
23DC	23E1	 # [6]
25B7		
25C1		
25F8	25FF	 # [8]
266F		
27C0	27C4	 # [5]
27C7	27CA	 # [4]
27CC		
27D0	27E5	 # [22]
27F0	27FF	 # [16]
2900	2982	 # [131]
2999	29D7	 # [63]
29DC	29FB	 # [32]
29FE	2AFF	 # [258]
2B30	2B44	 # [21]
2B47	2B4C	 # [6]
FB29		
FE62		
FE64	FE66	 # [3]
FF0B		
FF1C	FF1E	 # [3]
FF5C		
FF5E		
FFE2		
FFE9	FFEC	 # [4]
1D6C1		
1D6DB		
1D6FB		
1D715		
1D735		
1D74F		
1D76F		
1D789		
1D7A9		
1D7C3		
END
