# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 511 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Script=Greek}
#         \p{Sc=Grek}
#         \p{Is_Script=Greek}
#         \p{Is_Sc=Grek}
# 
#         \p{Greek}
#         \p{Is_Greek}
#         \p{Grek}
#         \p{Is_Grek}
# 
#     Note that contrary to what you might expect, the above is NOT the same
#     as \p{Greek_And_Coptic}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Sc: Greek}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0370	0373	 # [4]
0375	0377	 # [3]
037A	037D	 # [4]
0384		
0386		
0388	038A	 # [3]
038C		
038E	03A1	 # [20]
03A3	03E1	 # [63]
03F0	03FF	 # [16]
1D26	1D2A	 # [5]
1D5D	1D61	 # [5]
1D66	1D6A	 # [5]
1DBF		
1F00	1F15	 # [22]
1F18	1F1D	 # [6]
1F20	1F45	 # [38]
1F48	1F4D	 # [6]
1F50	1F57	 # [8]
1F59		
1F5B		
1F5D		
1F5F	1F7D	 # [31]
1F80	1FB4	 # [53]
1FB6	1FC4	 # [15]
1FC6	1FD3	 # [14]
1FD6	1FDB	 # [6]
1FDD	1FEF	 # [19]
1FF2	1FF4	 # [3]
1FF6	1FFE	 # [9]
2126		
10140	1018A	 # [75]
1D200	1D245	 # [70]
END
