# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 1_112_002 code points in Unicode Version 5.2.0 that
# match any of the following regular expression constructs:
# 
#         \p{Changes_When_Casemapped=No}
#         \p{CWCM=N}
#         \p{Is_Changes_When_Casemapped=F}
#         \p{Is_CWCM=False}
# 
#         \P{Changes_When_Casemapped}
#         \P{Is_Changes_When_Casemapped}
#         \P{CWCM}
#         \P{Is_CWCM}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_CWCM: No}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0000	0040	 # [65]
005B	0060	 # [6]
007B	00B4	 # [58]
00B6	00BF	 # [10]
00D7		
00F7		
0138		
018D		
019B		
01AA	01AB	 # [2]
01BA	01BB	 # [2]
01BE		
01C0	01C3	 # [4]
0221		
0234	0239	 # [6]
0255		
0258		
025A		
025C	025F	 # [4]
0261	0262	 # [2]
0264	0267	 # [4]
026A		
026C	026E	 # [3]
0270		
0273	0274	 # [2]
0276	027C	 # [7]
027E	027F	 # [2]
0281	0282	 # [2]
0284	0287	 # [4]
028D	0291	 # [5]
0293	0344	 # [178]
0346	036F	 # [42]
0374	0375	 # [2]
0378	037A	 # [3]
037E	0385	 # [8]
0387		
038B		
038D		
03A2		
03D2	03D4	 # [3]
03F3		
03F6		
03FC		
0482	0489	 # [8]
0526	0530	 # [11]
0557	0560	 # [10]
0588	109F	 # [2840]
10C6	1D78	 # [3251]
1D7A	1D7C	 # [3]
1D7E	1DFF	 # [130]
1E9C	1E9D	 # [2]
1E9F		
1F16	1F17	 # [2]
1F1E	1F1F	 # [2]
1F46	1F47	 # [2]
1F4E	1F4F	 # [2]
1F58		
1F5A		
1F5C		
1F5E		
1F7E	1F7F	 # [2]
1FB5		
1FBD		
1FBF	1FC1	 # [3]
1FC5		
1FCD	1FCF	 # [3]
1FD4	1FD5	 # [2]
1FDC	1FDF	 # [4]
1FED	1FF1	 # [5]
1FF5		
1FFD	2125	 # [297]
2127	2129	 # [3]
212C	2131	 # [6]
2133	214D	 # [27]
214F	215F	 # [17]
2180	2182	 # [3]
2185	24B5	 # [817]
24EA	2BFF	 # [1814]
2C2F		
2C5F		
2C71		
2C74		
2C77	2C7D	 # [7]
2CE4	2CEA	 # [7]
2CEF	2CFF	 # [17]
2D26	A63F	 # [31_002]
A660	A661	 # [2]
A66E	A67F	 # [18]
A698	A721	 # [138]
A730	A731	 # [2]
A770	A778	 # [9]
A788	A78A	 # [3]
A78D	FAFF	 # [21_363]
FB07	FB12	 # [12]
FB18	FF20	 # [1033]
FF3B	FF40	 # [6]
FF5B	103FF	 # [1189]
10450	10FFFF	 # [1_047_472]
END
