# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 429 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{General_Category=Other_Number}
#         \p{Gc=No}
#         \p{Category=Other_Number}
#         \p{Is_General_Category=No}
#         \p{Is_Gc=Other_Number}
#         \p{Is_Category=No}
# 
#         \p{Other_Number}
#         \p{Is_Other_Number}
#         \p{No}
#         \p{Is_No}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Category: Other_Number}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
00B2	00B3	 # [2]
00B9		
00BC	00BE	 # [3]
09F4	09F9	 # [6]
0BF0	0BF2	 # [3]
0C78	0C7E	 # [7]
0D70	0D75	 # [6]
0F2A	0F33	 # [10]
1369	137C	 # [20]
17F0	17F9	 # [10]
2070		
2074	2079	 # [6]
2080	2089	 # [10]
2150	215F	 # [16]
2189		
2460	249B	 # [60]
24EA	24FF	 # [22]
2776	2793	 # [30]
2CFD		
3192	3195	 # [4]
3220	3229	 # [10]
3251	325F	 # [15]
3280	3289	 # [10]
32B1	32BF	 # [15]
A830	A835	 # [6]
10107	10133	 # [45]
10175	10178	 # [4]
1018A		
10320	10323	 # [4]
10858	1085F	 # [8]
10916	1091B	 # [6]
10A40	10A47	 # [8]
10A7D	10A7E	 # [2]
10B58	10B5F	 # [8]
10B78	10B7F	 # [8]
10E60	10E7E	 # [31]
1D360	1D371	 # [18]
1F100	1F10A	 # [11]
END
