# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 1_109_945 code points in Unicode Version 5.2.0 that
# match any of the following regular expression constructs:
# 
#         \p{Default_Ignorable_Code_Point=No}
#         \p{DI=N}
#         \p{Is_Default_Ignorable_Code_Point=F}
#         \p{Is_DI=False}
# 
#         \P{Default_Ignorable_Code_Point}
#         \P{Is_Default_Ignorable_Code_Point}
#         \P{DI}
#         \P{Is_DI}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_DI: No}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0000	00AC	 # [173]
00AE	034E	 # [673]
0350	115E	 # [3599]
1161	17B3	 # [1619]
17B6	180A	 # [85]
180E	200A	 # [2045]
2010	2029	 # [26]
202F	205F	 # [49]
2070	3163	 # [4340]
3165	FDFF	 # [52_379]
FE10	FEFE	 # [239]
FF00	FF9F	 # [160]
FFA1	FFEF	 # [79]
FFF9	1D172	 # [53_626]
1D17B	DFFFF	 # [798_341]
E1000	10FFFF	 # [192_512]
END
