# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 523 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Script=Inherited}
#         \p{Sc=Zinh}
#         \p{Is_Script=Qaai}
#         \p{Is_Sc=Inherited}
# 
#         \p{Inherited}
#         \p{Is_Inherited}
#         \p{Zinh}
#         \p{Is_Zinh}
#         \p{Qaai}
#         \p{Is_Qaai}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Sc: Inherited}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0300	036F	 # [112]
0485	0486	 # [2]
064B	0655	 # [11]
0670		
0951	0952	 # [2]
1CD0	1CD2	 # [3]
1CD4	1CE0	 # [13]
1CE2	1CE8	 # [7]
1CED		
1DC0	1DE6	 # [39]
1DFD	1DFF	 # [3]
200C	200D	 # [2]
20D0	20F0	 # [33]
302A	302F	 # [6]
3099	309A	 # [2]
FE00	FE0F	 # [16]
FE20	FE26	 # [7]
101FD		
1D167	1D169	 # [3]
1D17B	1D182	 # [8]
1D185	1D18B	 # [7]
1D1AA	1D1AD	 # [4]
E0100	E01EF	 # [240]
END
