# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 1_114_066 code points in Unicode Version 5.2.0 that
# match any of the following regular expression constructs:
# 
#         \p{Soft_Dotted=No}
#         \p{SD=N}
#         \p{Is_Soft_Dotted=F}
#         \p{Is_SD=False}
# 
#         \P{Soft_Dotted}
#         \P{Is_Soft_Dotted}
#         \P{SD}
#         \P{Is_SD}
#         \P{_CanonDCIJ}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_SD: No}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0000	0068	 # [105]
006B	012E	 # [196]
0130	0248	 # [281]
024A	0267	 # [30]
0269	029C	 # [52]
029E	02B1	 # [20]
02B3	03F2	 # [320]
03F4	0455	 # [98]
0457		
0459	1D61	 # [6409]
1D63	1D95	 # [51]
1D97	1DA3	 # [13]
1DA5	1DA7	 # [3]
1DA9	1E2C	 # [132]
1E2E	1ECA	 # [157]
1ECC	2070	 # [421]
2072	2147	 # [214]
214A	2C7B	 # [2866]
2C7D	1D421	 # [108_453]
1D424	1D455	 # [50]
1D458	1D489	 # [50]
1D48C	1D4BD	 # [50]
1D4C0	1D4F1	 # [50]
1D4F4	1D525	 # [50]
1D528	1D559	 # [50]
1D55C	1D58D	 # [50]
1D590	1D5C1	 # [50]
1D5C4	1D5F5	 # [50]
1D5F8	1D629	 # [50]
1D62C	1D65D	 # [50]
1D660	1D691	 # [50]
1D694	10FFFF	 # [993_644]
END
