# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 71 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{General_Category=Close_Punctuation}
#         \p{Gc=Pe}
#         \p{Category=Close_Punctuation}
#         \p{Is_General_Category=Pe}
#         \p{Is_Gc=Close_Punctuation}
#         \p{Is_Category=Pe}
# 
#         \p{Close_Punctuation}
#         \p{Is_Close_Punctuation}
#         \p{Pe}
#         \p{Is_Pe}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Category: Close_Punctuation}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0029		
005D		
007D		
0F3B		
0F3D		
169C		
2046		
207E		
208E		
232A		
2769		
276B		
276D		
276F		
2771		
2773		
2775		
27C6		
27E7		
27E9		
27EB		
27ED		
27EF		
2984		
2986		
2988		
298A		
298C		
298E		
2990		
2992		
2994		
2996		
2998		
29D9		
29DB		
29FD		
2E23		
2E25		
2E27		
2E29		
3009		
300B		
300D		
300F		
3011		
3015		
3017		
3019		
301B		
301E	301F	 # [2]
FD3F		
FE18		
FE36		
FE38		
FE3A		
FE3C		
FE3E		
FE40		
FE42		
FE44		
FE48		
FE5A		
FE5C		
FE5E		
FF09		
FF3D		
FF5D		
FF60		
FF63		
END
