# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 2760 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Pattern_Syntax=Yes}
#         \p{Pat_Syn=Y}
#         \p{Is_Pattern_Syntax=T}
#         \p{Is_Pat_Syn=True}
# 
#         \p{Pattern_Syntax}
#         \p{Is_Pattern_Syntax}
#         \p{Pat_Syn}
#         \p{Is_Pat_Syn}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Pat_Syn: Yes}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0021	002F	 # [15]
003A	0040	 # [7]
005B	005E	 # [4]
0060		
007B	007E	 # [4]
00A1	00A7	 # [7]
00A9		
00AB	00AC	 # [2]
00AE		
00B0	00B1	 # [2]
00B6		
00BB		
00BF		
00D7		
00F7		
2010	2027	 # [24]
2030	203E	 # [15]
2041	2053	 # [19]
2055	205E	 # [10]
2190	245F	 # [720]
2500	2775	 # [630]
2794	2BFF	 # [1132]
2E00	2E7F	 # [128]
3001	3003	 # [3]
3008	3020	 # [25]
3030		
FD3E	FD3F	 # [2]
FE45	FE46	 # [2]
END
