# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 1016 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Age=3.2}
#         \p{Is_Age=3.2}
# 
#     Meaning: Code point's usage was introduced in version 3.2
# 
#     Note: See also Property 'Present_In'
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Age: 3.2}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0220		
034F		
0363	036F	 # [13]
03D8	03D9	 # [2]
03F6		
048A	048B	 # [2]
04C5	04C6	 # [2]
04C9	04CA	 # [2]
04CD	04CE	 # [2]
0500	050F	 # [16]
066E	066F	 # [2]
07B1		
10F7	10F8	 # [2]
1700	170C	 # [13]
170E	1714	 # [7]
1720	1736	 # [23]
1740	1753	 # [20]
1760	176C	 # [13]
176E	1770	 # [3]
1772	1773	 # [2]
2047		
204E	2052	 # [5]
2057		
205F	2063	 # [5]
2071		
20B0	20B1	 # [2]
20E4	20EA	 # [7]
213D	214B	 # [15]
21F4	21FF	 # [12]
22F2	22FF	 # [14]
237C		
239B	23CE	 # [52]
24EB	24FE	 # [20]
2596	259F	 # [10]
25F8	25FF	 # [8]
2616	2617	 # [2]
2672	267D	 # [12]
2680	2689	 # [10]
2768	2775	 # [14]
27D0	27EB	 # [28]
27F0	27FF	 # [16]
2900	2AFF	 # [512]
303B	303D	 # [3]
3095	3096	 # [2]
309F	30A0	 # [2]
30FF		
31F0	31FF	 # [16]
3251	325F	 # [15]
32B1	32BF	 # [15]
A4A2	A4A3	 # [2]
A4B4		
A4C1		
A4C5		
FA30	FA6A	 # [59]
FDFC		
FE00	FE0F	 # [16]
FE45	FE46	 # [2]
FE73		
FF5F	FF60	 # [2]
END
