# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 639 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Diacritic=Yes}
#         \p{Dia=Y}
#         \p{Is_Diacritic=T}
#         \p{Is_Dia=True}
# 
#         \p{Diacritic}
#         \p{Is_Diacritic}
#         \p{Dia}
#         \p{Is_Dia}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Dia: Yes}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
005E		
0060		
00A8		
00AF		
00B4		
00B7	00B8	 # [2]
02B0	034E	 # [159]
0350	0357	 # [8]
035D	0362	 # [6]
0374	0375	 # [2]
037A		
0384	0385	 # [2]
0483	0487	 # [5]
0559		
0591	05A1	 # [17]
05A3	05BD	 # [27]
05BF		
05C1	05C2	 # [2]
05C4		
064B	0652	 # [8]
0657	0658	 # [2]
06DF	06E0	 # [2]
06E5	06E6	 # [2]
06EA	06EC	 # [3]
0730	074A	 # [27]
07A6	07B0	 # [11]
07EB	07F5	 # [11]
0818	0819	 # [2]
093C		
094D		
0951	0954	 # [4]
0971		
09BC		
09CD		
0A3C		
0A4D		
0ABC		
0ACD		
0B3C		
0B4D		
0BCD		
0C4D		
0CBC		
0CCD		
0D4D		
0DCA		
0E47	0E4C	 # [6]
0E4E		
0EC8	0ECC	 # [5]
0F18	0F19	 # [2]
0F35		
0F37		
0F39		
0F3E	0F3F	 # [2]
0F82	0F84	 # [3]
0F86	0F87	 # [2]
0FC6		
1037		
1039	103A	 # [2]
1087	108D	 # [7]
108F		
109A	109B	 # [2]
17C9	17D3	 # [11]
17DD		
1939	193B	 # [3]
1A75	1A7C	 # [8]
1A7F		
1B34		
1B44		
1B6B	1B73	 # [9]
1BAA		
1C36	1C37	 # [2]
1C78	1C7D	 # [6]
1CD0	1CE8	 # [25]
1CED		
1D2C	1D6A	 # [63]
1DC4	1DCF	 # [12]
1DFD	1DFF	 # [3]
1FBD		
1FBF	1FC1	 # [3]
1FCD	1FCF	 # [3]
1FDD	1FDF	 # [3]
1FED	1FEF	 # [3]
1FFD	1FFE	 # [2]
2CEF	2CF1	 # [3]
2E2F		
302A	302F	 # [6]
3099	309C	 # [4]
30FC		
A66F		
A67C	A67D	 # [2]
A67F		
A6F0	A6F1	 # [2]
A717	A721	 # [11]
A788		
A8C4		
A8E0	A8F1	 # [18]
A92B	A92E	 # [4]
A953		
A9B3		
A9C0		
AA7B		
AABF	AAC2	 # [4]
ABEC	ABED	 # [2]
FB1E		
FE20	FE26	 # [7]
FF3E		
FF40		
FF70		
FF9E	FF9F	 # [2]
FFE3		
110B9	110BA	 # [2]
1D167	1D169	 # [3]
1D16D	1D172	 # [6]
1D17B	1D182	 # [8]
1D185	1D18B	 # [7]
1D1AA	1D1AD	 # [4]
END
