# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 99 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{General_Category=Modifier_Symbol}
#         \p{Gc=Sk}
#         \p{Category=Modifier_Symbol}
#         \p{Is_General_Category=Sk}
#         \p{Is_Gc=Modifier_Symbol}
#         \p{Is_Category=Sk}
# 
#         \p{Modifier_Symbol}
#         \p{Is_Modifier_Symbol}
#         \p{Sk}
#         \p{Is_Sk}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Category: Modifier_Symbol}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
005E		
0060		
00A8		
00AF		
00B4		
00B8		
02C2	02C5	 # [4]
02D2	02DF	 # [14]
02E5	02EB	 # [7]
02ED		
02EF	02FF	 # [17]
0375		
0384	0385	 # [2]
1FBD		
1FBF	1FC1	 # [3]
1FCD	1FCF	 # [3]
1FDD	1FDF	 # [3]
1FED	1FEF	 # [3]
1FFD	1FFE	 # [2]
309B	309C	 # [2]
A700	A716	 # [23]
A720	A721	 # [2]
A789	A78A	 # [2]
FF3E		
FF40		
FFE3		
END
