# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file is for tables that are not necessarily related:  To conserve
# resources, every table that matches the identical set of code points in
# this version of Unicode uses this file.  Each one is listed in a separate
# group below.  It could be that the tables will match the same set of code
# points in other Unicode releases, or it could be purely coincidence that
# they happen to be the same in Unicode 5.2.0, and hence may not in other
# versions.
# 
# This file returns the 1118 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Full_Composition_Exclusion=Yes}
#         \p{Comp_Ex=Y}
#         \p{Is_Full_Composition_Exclusion=T}
#         \p{Is_Comp_Ex=True}
# 
#         \p{Full_Composition_Exclusion}
#         \p{Is_Full_Composition_Exclusion}
#         \p{Comp_Ex}
#         \p{Is_Comp_Ex}
# 
#         \p{NFC_Quick_Check=No}
#         \p{NFC_QC=N}
#         \p{Is_NFC_Quick_Check=No}
#         \p{Is_NFC_QC=N}
# 
#     Note that contrary to what you might expect, the above is NOT the same
#     as any of: \P{NFC_Quick_Check}, \P{NFC_QC}, \P{Is_NFC_Quick_Check},
#     \P{Is_NFC_QC}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and within each group
# above, anything to the left of the equals (or colon) can be combined with
# anything to the right.  Thus, for example,
#         \p{Is_NFC_QC: No}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0340	0341	 # [2]
0343	0344	 # [2]
0374		
037E		
0387		
0958	095F	 # [8]
09DC	09DD	 # [2]
09DF		
0A33		
0A36		
0A59	0A5B	 # [3]
0A5E		
0B5C	0B5D	 # [2]
0F43		
0F4D		
0F52		
0F57		
0F5C		
0F69		
0F73		
0F75	0F76	 # [2]
0F78		
0F81		
0F93		
0F9D		
0FA2		
0FA7		
0FAC		
0FB9		
1F71		
1F73		
1F75		
1F77		
1F79		
1F7B		
1F7D		
1FBB		
1FBE		
1FC9		
1FCB		
1FD3		
1FDB		
1FE3		
1FEB		
1FEE	1FEF	 # [2]
1FF9		
1FFB		
1FFD		
2000	2001	 # [2]
2126		
212A	212B	 # [2]
2329	232A	 # [2]
2ADC		
F900	FA0D	 # [270]
FA10		
FA12		
FA15	FA1E	 # [10]
FA20		
FA22		
FA25	FA26	 # [2]
FA2A	FA2D	 # [4]
FA30	FA6D	 # [62]
FA70	FAD9	 # [106]
FB1D		
FB1F		
FB2A	FB36	 # [13]
FB38	FB3C	 # [5]
FB3E		
FB40	FB41	 # [2]
FB43	FB44	 # [2]
FB46	FB4E	 # [9]
1D15E	1D164	 # [7]
1D1BB	1D1C0	 # [6]
2F800	2FA1D	 # [542]
END
