# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 46 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Soft_Dotted=Yes}
#         \p{SD=Y}
#         \p{Is_Soft_Dotted=T}
#         \p{Is_SD=True}
# 
#         \p{Soft_Dotted}
#         \p{Is_Soft_Dotted}
#         \p{SD}
#         \p{Is_SD}
#         \p{_CanonDCIJ}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_SD: Yes}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0069	006A	 # [2]
012F		
0249		
0268		
029D		
02B2		
03F3		
0456		
0458		
1D62		
1D96		
1DA4		
1DA8		
1E2D		
1ECB		
2071		
2148	2149	 # [2]
2C7C		
1D422	1D423	 # [2]
1D456	1D457	 # [2]
1D48A	1D48B	 # [2]
1D4BE	1D4BF	 # [2]
1D4F2	1D4F3	 # [2]
1D526	1D527	 # [2]
1D55A	1D55B	 # [2]
1D58E	1D58F	 # [2]
1D5C2	1D5C3	 # [2]
1D5F6	1D5F7	 # [2]
1D62A	1D62B	 # [2]
1D65E	1D65F	 # [2]
1D692	1D693	 # [2]
END
