# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 543 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Bidi_Mirrored=Yes}
#         \p{Bidi_M=Y}
#         \p{Is_Bidi_Mirrored=T}
#         \p{Is_Bidi_M=True}
# 
#         \p{Bidi_Mirrored}
#         \p{Is_Bidi_Mirrored}
#         \p{Bidi_M}
#         \p{Is_Bidi_M}
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Bidi_M: Yes}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0028	0029	 # [2]
003C		
003E		
005B		
005D		
007B		
007D		
00AB		
00BB		
0F3A	0F3D	 # [4]
169B	169C	 # [2]
2039	203A	 # [2]
2045	2046	 # [2]
207D	207E	 # [2]
208D	208E	 # [2]
2140		
2201	2204	 # [4]
2208	220D	 # [6]
2211		
2215	2216	 # [2]
221A	221D	 # [4]
221F	2222	 # [4]
2224		
2226		
222B	2233	 # [9]
2239		
223B	224C	 # [18]
2252	2255	 # [4]
225F	2260	 # [2]
2262		
2264	226B	 # [8]
226E	228C	 # [31]
228F	2292	 # [4]
2298		
22A2	22A3	 # [2]
22A6	22B8	 # [19]
22BE	22BF	 # [2]
22C9	22CD	 # [5]
22D0	22D1	 # [2]
22D6	22ED	 # [24]
22F0	22FF	 # [16]
2308	230B	 # [4]
2320	2321	 # [2]
2329	232A	 # [2]
2768	2775	 # [14]
27C0		
27C3	27C6	 # [4]
27C8	27C9	 # [2]
27CC		
27D3	27D6	 # [4]
27DC	27DE	 # [3]
27E2	27EF	 # [14]
2983	2998	 # [22]
299B	29AF	 # [21]
29B8		
29C0	29C5	 # [6]
29C9		
29CE	29D2	 # [5]
29D4	29D5	 # [2]
29D8	29DC	 # [5]
29E1		
29E3	29E5	 # [3]
29E8	29E9	 # [2]
29F4	29F9	 # [6]
29FC	29FD	 # [2]
2A0A	2A1C	 # [19]
2A1E	2A21	 # [4]
2A24		
2A26		
2A29		
2A2B	2A2E	 # [4]
2A34	2A35	 # [2]
2A3C	2A3E	 # [3]
2A57	2A58	 # [2]
2A64	2A65	 # [2]
2A6A	2A6D	 # [4]
2A6F	2A70	 # [2]
2A73	2A74	 # [2]
2A79	2AA3	 # [43]
2AA6	2AAD	 # [8]
2AAF	2AD6	 # [40]
2ADC		
2ADE		
2AE2	2AE6	 # [5]
2AEC	2AEE	 # [3]
2AF3		
2AF7	2AFB	 # [5]
2AFD		
2E02	2E05	 # [4]
2E09	2E0A	 # [2]
2E0C	2E0D	 # [2]
2E1C	2E1D	 # [2]
2E20	2E29	 # [10]
3008	3011	 # [10]
3014	301B	 # [8]
FE59	FE5E	 # [6]
FE64	FE65	 # [2]
FF08	FF09	 # [2]
FF1C		
FF1E		
FF3B		
FF3D		
FF5B		
FF5D		
FF5F	FF60	 # [2]
FF62	FF63	 # [2]
1D6DB		
1D715		
1D74F		
1D789		
1D7C3		
END
