# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 1226 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Age=4.0}
#         \p{Is_Age=4.0}
# 
#     Meaning: Code point's usage was introduced in version 4.0
# 
#     Note: See also Property 'Present_In'
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Age: 4.0}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0221		
0234	0236	 # [3]
02AE	02AF	 # [2]
02EF	02FF	 # [17]
0350	0357	 # [8]
035D	035F	 # [3]
03F7	03FB	 # [5]
0600	0603	 # [4]
060D	0615	 # [9]
0656	0658	 # [3]
06EE	06EF	 # [2]
06FF		
072D	072F	 # [3]
074D	074F	 # [3]
0904		
09BD		
0A01		
0A03		
0A8C		
0AE1	0AE3	 # [3]
0AF1		
0B35		
0B71		
0BF3	0BFA	 # [8]
0CBC	0CBD	 # [2]
17DD		
17F0	17F9	 # [10]
1900	191C	 # [29]
1920	192B	 # [12]
1930	193B	 # [12]
1940		
1944	196D	 # [42]
1970	1974	 # [5]
19E0	19FF	 # [32]
1D00	1D6B	 # [108]
2053	2054	 # [2]
213B		
23CF	23D0	 # [2]
24FF		
2614	2615	 # [2]
268A	2691	 # [8]
26A0	26A1	 # [2]
2B00	2B0D	 # [14]
321D	321E	 # [2]
3250		
327C	327D	 # [2]
32CC	32CF	 # [4]
3377	337A	 # [4]
33DE	33DF	 # [2]
33FF		
4DC0	4DFF	 # [64]
FDFD		
FE47	FE48	 # [2]
10000	1000B	 # [12]
1000D	10026	 # [26]
10028	1003A	 # [19]
1003C	1003D	 # [2]
1003F	1004D	 # [15]
10050	1005D	 # [14]
10080	100FA	 # [123]
10100	10102	 # [3]
10107	10133	 # [45]
10137	1013F	 # [9]
10380	1039D	 # [30]
1039F		
10426	10427	 # [2]
1044E	1049D	 # [80]
104A0	104A9	 # [10]
10800	10805	 # [6]
10808		
1080A	10835	 # [44]
10837	10838	 # [2]
1083C		
1083F		
1D300	1D356	 # [87]
1D4C1		
E0100	E01EF	 # [240]
END
