# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 5.2.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by the Perl program only.  The format and even
# the name or existence of this file are subject to change without notice.
# Don't use it directly.

# This file returns the 1369 code points in Unicode Version 5.2.0 that match
# any of the following regular expression constructs:
# 
#         \p{Age=5.0}
#         \p{Is_Age=5.0}
# 
#     Meaning: Code point's usage was introduced in version 5.0
# 
#     Note: See also Property 'Present_In'
# 
# perluniprops.pod should be consulted for the syntax rules for any of these,
# including if adding or subtracting white space, underscore, and hyphen
# characters matters or doesn't matter, and other permissible syntactic
# variants.  Upper/lower case distinctions never matter.
# 
# A colon can be substituted for the equals sign, and anything to the left of
# the equals (or colon) can be combined with anything to the right.  Thus,
# for example,
#         \p{Is_Age: 5.0}
# is also valid.
# 
# The format of the lines of this file is: START\tSTOP\twhere START is the
# starting code point of the range, in hex; STOP is the ending point, or if
# omitted, the range has just one code point.  Numbers in comments in
# [brackets] indicate how many code points are in the range.

return <<'END';
0242	024F	 # [14]
037B	037D	 # [3]
04CF		
04FA	04FF	 # [6]
0510	0513	 # [4]
05BA		
07C0	07FA	 # [59]
097B	097C	 # [2]
097E	097F	 # [2]
0CE2	0CE3	 # [2]
0CF1	0CF2	 # [2]
1B00	1B4B	 # [76]
1B50	1B7C	 # [45]
1DC4	1DCA	 # [7]
1DFE	1DFF	 # [2]
20EC	20EF	 # [4]
214D	214E	 # [2]
2184		
23DC	23E7	 # [12]
26B2		
27C7	27CA	 # [4]
2B14	2B1A	 # [7]
2B20	2B23	 # [4]
2C60	2C6C	 # [13]
2C74	2C77	 # [4]
A717	A71A	 # [4]
A720	A721	 # [2]
A840	A877	 # [56]
10900	10919	 # [26]
1091F		
12000	1236E	 # [879]
12400	12462	 # [99]
12470	12473	 # [4]
1D360	1D371	 # [18]
1D7CA	1D7CB	 # [2]
END
